@@ -21,19 +21,16 @@ require "kitchen/command"
 require "benchmark"
 
 module Kitchen
-
   module Command
-
     # Command to test one or more instances.
     #
     # @author Fletcher Nichol <fnichol@nichol.ca>
     class Test < Kitchen::Command::Base
-
       include RunAction
 
       # Invoke the command.
       def call
-        if !%w[passing always never].include?(options[:destroy])
+        unless %w{passing always never}.include?(options[:destroy])
           raise ArgumentError, "Destroy mode must be passing, always, or never."
         end
 
