@@ -21,14 +21,12 @@ require "thor/util"
 require "kitchen/lazy_hash"
 
 module Kitchen
-
   # A mixin for providing configuration-related behavior such as default
   # config (static, computed, inherited), required config, local path
   # expansion, etc.
   #
   # @author Fletcher Nichol <fnichol@nichol.ca>
   module Configurable
-
     def self.included(base)
       base.extend(ClassMethods)
     end
@@ -46,12 +44,11 @@ module Kitchen
     # @return [self] itself, for use in chaining
     # @raise [ClientError] if instance parameter is nil
     def finalize_config!(instance)
-      if instance.nil?
-        raise ClientError, "Instance must be provided to #{self}"
-      end
+      raise ClientError, "Instance must be provided to #{self}" if instance.nil?
 
       @instance = instance
       expand_paths!
+      deprecate_config!
       validate_config!
       load_needed_dependencies!
 
@@ -102,7 +99,7 @@ module Kitchen
       [
         File.join(base, instance.suite.name, path),
         File.join(base, path),
-        File.join(Dir.pwd, path)
+        File.join(Dir.pwd, path),
       ].find do |candidate|
         type == :directory ? File.directory?(candidate) : File.file?(candidate)
       end
@@ -119,7 +116,7 @@ module Kitchen
     #
     # @return [Hash] a diagnostic hash
     def diagnose
-      result = Hash.new
+      result = {}
       config_keys.sort.each { |k| result[k] = config[k] }
       result
     end
@@ -130,7 +127,7 @@ module Kitchen
     #
     # @return [Hash] a diagnostic hash
     def diagnose_plugin
-      result = Hash.new
+      result = {}
       result[:name] = name
       result.merge!(self.class.diagnose)
       result
@@ -153,7 +150,7 @@ module Kitchen
     # @return [String] joined path for instance's os_type
     def remote_path_join(*parts)
       path = File.join(*parts)
-      windows_os? ? path.gsub("/", "\\") : path.gsub("\\", "/")
+      windows_os? ? path.tr("/", '\\') : path.tr('\\', "/")
     end
 
     # @return [TrueClass,FalseClass] true if `:os_type` is `"unix"` (or
@@ -184,6 +181,14 @@ module Kitchen
     # @api private
     attr_reader :config
 
+    # @return [Hash] a hash of the detected deprecated config attributes
+    # @api private
+    attr_reader :deprecated_config
+
+    # @return [Hash] user provided configuration hash
+    # @api private
+    attr_reader :provided_config
+
     # Initializes an internal configuration hash. The hash may contain
     # callable blocks as values that are meant to be called lazily. This
     # method is intended to be included in an object's .initialize method.
@@ -192,6 +197,7 @@ module Kitchen
     # @api private
     def init_config(config)
       @config = LazyHash.new(config, self)
+      @provided_config = config.dup
       self.class.defaults.each do |attr, value|
         @config[attr] = value unless @config.key?(attr)
       end
@@ -210,10 +216,36 @@ module Kitchen
         next if !should_expand || config[key].nil? || config[key] == false
 
         config[key] = if config[key].is_a?(Array)
-          config[key].map { |path| File.expand_path(path, root_path) }
-        else
-          File.expand_path(config[key], root_path)
-        end
+                        config[key].map { |path| File.expand_path(path, root_path) }
+                      else
+                        File.expand_path(config[key], root_path)
+                      end
+      end
+    end
+
+    # Initialize detected deprecated configuration hash.
+    # Display warning if deprecations have been detected.
+    #
+    # @api private
+    def deprecate_config!
+      # We only want to display the deprecation list of config values once per execution on the default config.
+      # This prevents the output of deprecations from being printed for each permutation of test suites.
+      return if defined? @@has_been_warned_of_deprecations
+
+      deprecated_attributes = LazyHash.new(self.class.deprecated_attributes, self)
+      # Remove items from hash when not provided in the loaded config or when the rendered message is nil
+      @deprecated_config = deprecated_attributes.delete_if { |attr, obj| !provided_config.key?(attr) || obj.nil? }
+
+      if !deprecated_config.empty?
+        warning = Util.outdent!(<<-MSG)
+          Deprecated configuration detected:
+          #{deprecated_config.keys.join("\n")}
+          Run 'kitchen doctor' for details.
+        MSG
+        warn(warning)
+
+        # Set global var that the deprecation message has been printed
+        @@has_been_warned_of_deprecations = true
       end
     end
 
@@ -254,9 +286,10 @@ module Kitchen
     # @api private
     def reload_ps1_path
       [
-        %{$env:PATH},
-        %{[System.Environment]::GetEnvironmentVariable("PATH","Machine")\n\n}
-      ].join(" = ")
+        "$env:PATH = try {",
+        "[System.Environment]::GetEnvironmentVariable('PATH','Machine')",
+        "} catch { $env:PATH }\n\n",
+      ].join("\n")
     end
 
     # Builds a shell environment variable assignment string for the
@@ -307,12 +340,12 @@ module Kitchen
     # @return [String] wrapped shell code
     # @api private
     def wrap_shell_code(code)
-      return env_wrapped code if powershell_shell?
+      return env_wrapped(code) if powershell_shell?
       Util.wrap_command((env_wrapped code))
     end
 
     def env_wrapped(code)
-      code_parts = proxy_settings
+      code_parts = resolve_proxy_settings_from_config
       code_parts << shell_env_var("TEST_KITCHEN", 1)
       code_parts << shell_env_var("CI", ENV["CI"]) if ENV["CI"]
       code_parts << code
@@ -320,7 +353,7 @@ module Kitchen
     end
 
     def proxy_setting_keys
-      [:http_proxy, :https_proxy, :ftp_proxy]
+      [:http_proxy, :https_proxy, :ftp_proxy, :no_proxy]
     end
 
     def resolve_proxy_settings_from_config
@@ -328,25 +361,12 @@ module Kitchen
         if !config.key?(protocol) || config[protocol].nil?
           export_proxy(set_env, protocol)
         elsif proxy_config_setting_present?(protocol)
-          set_env << shell_env_var("#{protocol.downcase}", config[protocol])
-          set_env << shell_env_var("#{protocol.upcase}", config[protocol])
+          set_env << shell_env_var(protocol.downcase.to_s, config[protocol])
+          set_env << shell_env_var(protocol.upcase.to_s, config[protocol])
         end
       end
     end
 
-    def proxy_settings
-      env = resolve_proxy_settings_from_config
-
-      # if http_proxy was set from environment variable or https_proxy was set
-      # from environment variable, or ftp_proxy was set from environment
-      # variable, include no_proxy environment variable, if set.
-      if !proxy_from_config? && proxy_from_environment?
-        env << shell_env_var("no_proxy", ENV["no_proxy"]) if ENV["no_proxy"]
-        env << shell_env_var("NO_PROXY", ENV["NO_PROXY"]) if ENV["NO_PROXY"]
-      end
-      env
-    end
-
     def proxy_from_config?
       proxy_setting_keys.any? do |protocol|
         !config[protocol].nil?
@@ -355,7 +375,7 @@ module Kitchen
 
     def proxy_from_environment?
       proxy_setting_keys.any? do |protocol|
-        !ENV["#{protocol.downcase}"].nil? || !ENV["#{protocol.upcase}"].nil?
+        !ENV[protocol.downcase.to_s].nil? || !ENV[protocol.upcase.to_s].nil?
       end
     end
 
@@ -369,14 +389,13 @@ module Kitchen
     # @param code [String] the type of proxy to export, one of 'http', 'https' or 'ftp'
     # @api private
     def export_proxy(env, type)
-      env << shell_env_var("#{type}", ENV["#{type}"]) if ENV["#{type}"]
-      env << shell_env_var("#{type.upcase}", ENV["#{type.upcase}"]) if
-        ENV["#{type.upcase}"]
+      env << shell_env_var(type.to_s, ENV[type.to_s]) if ENV[type.to_s]
+      env << shell_env_var(type.upcase.to_s, ENV[type.upcase.to_s]) if
+        ENV[type.upcase.to_s]
     end
 
     # Class methods which will be mixed in on inclusion of Configurable module.
     module ClassMethods
-
       # Sets the loaded version of this plugin, usually corresponding to the
       # RubyGems version of the plugin's library. If the plugin does not set
       # this value, then `nil` will be used and reported.
@@ -406,9 +425,9 @@ module Kitchen
       # @return [Hash] a diagnostic hash
       def diagnose
         {
-          :class        => name,
-          :version      => @plugin_version,
-          :api_version  => @api_version
+          class: name,
+          version: @plugin_version ||= nil,
+          api_version: @api_version ||= nil,
         }
       end
 
@@ -468,6 +487,26 @@ module Kitchen
         expanded_paths[attr] = block_given? ? block : value
       end
 
+      # Set the appropriate deprecation message for a given attribute name
+      #
+      # @example the default usage
+      #
+      #   deprecate_config_for :attribute_name, "Detailed deprecation message."
+      #
+      # @example using a block
+      #
+      #   deprecate_config_for :attribute_name do |subject|
+      #     "Detailed deprecation message." if subject == true
+      #   end
+      #
+      # @param attr [String] configuration attribute name
+      # @param value [Object, nil] static default value for attribute
+      # @yieldparam object [Object] a reference to the instantiated object
+      # @yieldreturn [Object, nil] dynamically computed value for the attribute
+      def deprecate_config_for(attr, value = nil, &block)
+        deprecated_attributes[attr] = block_given? ? block : value
+      end
+
       # Ensures that an attribute must have a non-nil, non-empty String value.
       # The default behavior will be to raise a user error and thereby halting
       # further configuration processing. Good use cases for require_config
@@ -488,7 +527,7 @@ module Kitchen
       # @yieldparam value [Object] the current value of the attribute
       # @yieldparam object [Object] a reference to the instantiated object
       def required_config(attr, &block)
-        if !block_given?
+        unless block_given?
           klass = self
           block = lambda do |_, value, thing|
             if value.nil? || value.to_s.empty?
@@ -504,7 +543,7 @@ module Kitchen
       #   been merged with any superclass defaults
       # @api private
       def defaults
-        @defaults ||= Hash.new.merge(super_defaults)
+        @defaults ||= {}.merge(super_defaults)
       end
 
       # @return [Hash] a hash of defaults from the included class' superclass
@@ -514,7 +553,7 @@ module Kitchen
         if superclass.respond_to?(:defaults)
           superclass.defaults
         else
-          Hash.new
+          {}
         end
       end
 
@@ -523,7 +562,7 @@ module Kitchen
       #   which has been merged with any superclass expanded paths
       # @api private
       def expanded_paths
-        @expanded_paths ||= Hash.new.merge(super_expanded_paths)
+        @expanded_paths ||= {}.merge(super_expanded_paths)
       end
 
       # @return [Hash] a hash of expanded paths from the included class'
@@ -533,7 +572,19 @@ module Kitchen
         if superclass.respond_to?(:expanded_paths)
           superclass.expanded_paths
         else
-          Hash.new
+          {}
+        end
+      end
+
+      def deprecated_attributes
+        @deprecated_attributes ||= {}.merge(super_deprecated_attributes)
+      end
+
+      def super_deprecated_attributes
+        if superclass.respond_to?(:deprecated_attributes)
+          superclass.deprecated_attributes
+        else
+          {}
         end
       end
 
@@ -541,7 +592,7 @@ module Kitchen
       #   which has been merged with any superclass valudations
       # @api private
       def validations
-        @validations ||= Hash.new.merge(super_validations)
+        @validations ||= {}.merge(super_validations)
       end
 
       # @return [Hash] a hash of validations from the included class'
@@ -551,7 +602,7 @@ module Kitchen
         if superclass.respond_to?(:validations)
           superclass.validations
         else
-          Hash.new
+          {}
         end
       end
     end
