@@ -19,7 +19,6 @@
 require "vendor/hash_recursive_merge"
 
 module Kitchen
-
   # Class to handle recursive merging of configuration between platforms,
   # suites, and common data.
   #
@@ -32,7 +31,6 @@ module Kitchen
   #
   # @author Fletcher Nichol <fnichol@nichol.ca>
   class DataMunger
-
     # Constructs a new DataMunger object.
     #
     # @param data [Hash] the incoming user data hash
@@ -47,6 +45,7 @@ module Kitchen
       convert_legacy_busser_format!
       convert_legacy_driver_http_proxy_format!
       move_chef_data_to_provisioner!
+      convert_legacy_pre_create_command!
     end
 
     # Generate a new Hash of configuration data that can be used to construct
@@ -64,6 +63,25 @@ module Kitchen
       end
     end
 
+    # Generate a new Hash of configuration data that can be used to construct
+    # a new LifecycleHooks object.
+    #
+    # @param suite [String] a suite name
+    # @param platform [String] a platform name
+    # @return [Hash] a new configuration Hash that can be used to construct a
+    #   new LifecycleHooks
+    def lifecycle_hooks_data_for(suite, platform)
+      merged_data_for(:lifecycle, suite, platform).tap do |lhdata|
+        lhdata.each_key do |k|
+          combine_arrays!(lhdata, k, :common, :platform, :suite)
+        end
+        set_kitchen_config_at!(lhdata, :kitchen_root)
+        set_kitchen_config_at!(lhdata, :test_base_path)
+        set_kitchen_config_at!(lhdata, :log_level)
+        set_kitchen_config_at!(lhdata, :debug)
+      end
+    end
+
     # Returns an Array of platform Hashes.
     #
     # @return [Array<Hash>] an Array of Hashes
@@ -82,6 +100,7 @@ module Kitchen
       merged_data_for(:provisioner, suite, platform).tap do |pdata|
         set_kitchen_config_at!(pdata, :kitchen_root)
         set_kitchen_config_at!(pdata, :test_base_path)
+        set_kitchen_config_at!(pdata, :debug)
         combine_arrays!(pdata, :run_list, :platform, :suite)
       end
     end
@@ -120,6 +139,7 @@ module Kitchen
         set_kitchen_config_at!(vdata, :kitchen_root)
         set_kitchen_config_at!(vdata, :test_base_path)
         set_kitchen_config_at!(vdata, :log_level)
+        set_kitchen_config_at!(vdata, :debug)
       end
     end
 
@@ -135,9 +155,9 @@ module Kitchen
 
     def combine_arrays!(root, key, *namespaces)
       if root.key?(key)
-        root[key] = namespaces.
-          map { |namespace| root.fetch(key).fetch(namespace, []) }.flatten.
-          compact
+        root[key] = namespaces
+                    .map { |namespace| root.fetch(key).fetch(namespace, []) }.flatten
+                    .compact
       end
     end
 
@@ -151,7 +171,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :busser => "bar"
     #       }
     #     ],
@@ -174,7 +194,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :verifier => {
     #           :name => "busser",
     #           :version => "bar
@@ -219,11 +239,11 @@ module Kitchen
     def convert_legacy_busser_format_at!(root)
       if root.key?(:busser)
         bdata = root.delete(:busser)
-        bdata = { :version => bdata } if bdata.is_a?(String)
+        bdata = { version: bdata } if bdata.is_a?(String)
         bdata[:name] = "busser" if bdata[:name].nil?
 
-        vdata = root.fetch(:verifier, Hash.new)
-        vdata = { :name => vdata } if vdata.is_a?(String)
+        vdata = root.fetch(:verifier, {})
+        vdata = { name: vdata } if vdata.is_a?(String)
         root[:verifier] = bdata.rmerge(vdata)
       end
     end
@@ -275,10 +295,10 @@ module Kitchen
     # @api private
     def convert_legacy_chef_paths_format!
       data.fetch(:suites, []).each do |suite|
-        %w[
+        %w{
           data data_bags encrypted_data_bag_secret_key
           environments nodes roles
-        ].each do |key|
+        }.each do |key|
           move_chef_data_to_provisioner_at!(suite, "#{key}_path".to_sym)
         end
       end
@@ -295,7 +315,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :driver_plugin => "bar"
     #       }
     #     ],
@@ -319,7 +339,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :driver => {
     #           :name => "bar"
     #         }
@@ -364,15 +384,15 @@ module Kitchen
     # @api private
     def convert_legacy_driver_format_at!(root)
       if root.key?(:driver_config)
-        ddata = root.fetch(:driver, Hash.new)
-        ddata = { :name => ddata } if ddata.is_a?(String)
+        ddata = root.fetch(:driver, {})
+        ddata = { name: ddata } if ddata.is_a?(String)
         root[:driver] = root.delete(:driver_config).rmerge(ddata)
       end
 
       if root.key?(:driver_plugin)
-        ddata = root.fetch(:driver, Hash.new)
-        ddata = { :name => ddata } if ddata.is_a?(String)
-        root[:driver] = { :name => root.delete(:driver_plugin) }.rmerge(ddata)
+        ddata = root.fetch(:driver, {})
+        ddata = { name: ddata } if ddata.is_a?(String)
+        root[:driver] = { name: root.delete(:driver_plugin) }.rmerge(ddata)
       end
     end
 
@@ -391,7 +411,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :driver => {
     #           :http_proxy => "foo"
     #         }
@@ -428,7 +448,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :driver => {
     #           :http_proxy => "foo"
     #         },
@@ -485,17 +505,17 @@ module Kitchen
     #   longer are Drivers responsible for this.
     # @api private
     def convert_legacy_driver_http_proxy_format_at!(root)
-      ddata = root.fetch(:driver, Hash.new)
+      ddata = root.fetch(:driver, {})
 
       [:http_proxy, :https_proxy].each do |key|
         next unless ddata.is_a?(Hash) && ddata.key?(key)
 
-        pdata = root.fetch(:provisioner, Hash.new)
-        pdata = { :name => pdata } if pdata.is_a?(String)
+        pdata = root.fetch(:provisioner, {})
+        pdata = { name: pdata } if pdata.is_a?(String)
         root[:provisioner] = { key => ddata.fetch(key) }.rmerge(pdata)
 
-        vdata = root.fetch(:verifier, Hash.new)
-        vdata = { :name => vdata } if vdata.is_a?(String)
+        vdata = root.fetch(:verifier, {})
+        vdata = { name: vdata } if vdata.is_a?(String)
         root[:verifier] = { key => ddata.fetch(key) }.rmerge(vdata)
       end
     end
@@ -512,7 +532,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :driver => {
     #           :require_chef_omnibus => "10.8.2"
     #         }
@@ -538,7 +558,7 @@ module Kitchen
     #
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :provisioner => {
     #           :require_chef_omnibus => "10.8.2"
     #         }
@@ -581,16 +601,37 @@ module Kitchen
     # @api private
     def convert_legacy_require_chef_omnibus_format_at!(root)
       key = :require_chef_omnibus
-      ddata = root.fetch(:driver, Hash.new)
+      ddata = root.fetch(:driver, {})
 
       if ddata.is_a?(Hash) && ddata.key?(key)
-        pdata = root.fetch(:provisioner, Hash.new)
-        pdata = { :name => pdata } if pdata.is_a?(String)
+        pdata = root.fetch(:provisioner, {})
+        pdata = { name: pdata } if pdata.is_a?(String)
         root[:provisioner] =
           { key => root.fetch(:driver).delete(key) }.rmerge(pdata)
       end
     end
 
+    def convert_legacy_pre_create_command!
+      convert_legacy_pre_create_command_at!(data)
+      data.fetch(:platforms, []).each do |platform|
+        convert_legacy_pre_create_command_at!(platform)
+      end
+      data.fetch(:suites, []).each do |suite|
+        convert_legacy_pre_create_command_at!(suite)
+      end
+    end
+
+    def convert_legacy_pre_create_command_at!(root)
+      ddata = root[:driver] || {}
+      if ddata.is_a?(Hash) && ddata.include?(:pre_create_command)
+        root[:lifecycle] ||= {}
+        root[:lifecycle][:pre_create] ||= []
+        root[:lifecycle][:pre_create] = Array(root[:lifecycle][:pre_create])
+        root[:lifecycle][:pre_create] << { local: ddata[:pre_create_command] }
+        ddata.delete(:pre_create_command)
+      end
+    end
+
     # Performs a prioritized recursive merge of several source Hashes and
     # returns a new merged Hash. For these data sub-hash structures, there are
     # 4 sources for configuration data:
@@ -635,7 +676,7 @@ module Kitchen
     #   {
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :attributes => { :one => "two" },
     #         :run_list => ["alpha", "bravo"]
     #       }
@@ -655,7 +696,7 @@ module Kitchen
     #   {
     #     :platforms => [
     #       {
-    #         :name => "ubuntu-12.04",
+    #         :name => "ubuntu-16.04",
     #         :provisioner => {
     #           :attributes => { :one => "two" },
     #           :run_list => ["alpha", "bravo"]
@@ -699,9 +740,9 @@ module Kitchen
     # @api private
     def move_chef_data_to_provisioner_at!(root, key)
       if root.key?(key)
-        pdata = root.fetch(:provisioner, Hash.new)
-        pdata = { :name => pdata } if pdata.is_a?(String)
-        if !root.fetch(key, nil).nil?
+        pdata = root.fetch(:provisioner, {})
+        pdata = { name: pdata } if pdata.is_a?(String)
+        unless root.fetch(key, nil).nil?
           root[:provisioner] = pdata.rmerge(key => root.delete(key))
         end
       end
@@ -755,9 +796,15 @@ module Kitchen
     #   new Hash otherwise
     # @api private
     def normalized_common_data(key, default_key)
-      cdata = data.fetch(key, Hash.new)
-      cdata = cdata.nil? ? Hash.new : cdata.dup
+      cdata = data.fetch(key, {})
+      cdata = cdata.nil? ? {} : cdata.dup
       cdata = { default_key => cdata } if cdata.is_a?(String)
+      case key
+      when :lifecycle
+        cdata.each_key do |k|
+          namespace_array!(cdata, k, :common)
+        end
+      end
       cdata
     end
 
@@ -799,7 +846,7 @@ module Kitchen
     #   new Hash otherwise
     # @api private
     def normalized_default_data(key, default_key, suite, platform)
-      ddata = kitchen_config.fetch(:defaults, Hash.new).fetch(key, Hash.new).dup
+      ddata = kitchen_config.fetch(:defaults, {}).fetch(key, {}).dup
       ddata = { default_key => ddata.call(suite, platform) } if ddata.is_a?(Proc)
       ddata = { default_key => ddata } if ddata.is_a?(String)
       ddata
@@ -853,10 +900,17 @@ module Kitchen
     #   new Hash otherwise
     # @api private
     def normalized_platform_data(key, default_key, platform)
-      pdata = platform_data_for(platform).fetch(key, Hash.new)
-      pdata = pdata.nil? ? Hash.new : pdata.dup
+      pdata = platform_data_for(platform).fetch(key, {})
+      pdata = pdata.nil? ? {} : pdata.dup
       pdata = { default_key => pdata } if pdata.is_a?(String)
-      namespace_array!(pdata, :run_list, :platform)
+      case key
+      when :provisioner
+        namespace_array!(pdata, :run_list, :platform)
+      when :lifecycle
+        pdata.each_key do |k|
+          namespace_array!(pdata, k, :platform)
+        end
+      end
       pdata
     end
 
@@ -908,10 +962,17 @@ module Kitchen
     #   new Hash otherwise
     # @api private
     def normalized_suite_data(key, default_key, suite)
-      sdata = suite_data_for(suite).fetch(key, Hash.new)
-      sdata = sdata.nil? ? Hash.new : sdata.dup
+      sdata = suite_data_for(suite).fetch(key, {})
+      sdata = sdata.nil? ? {} : sdata.dup
       sdata = { default_key => sdata } if sdata.is_a?(String)
-      namespace_array!(sdata, :run_list, :suite)
+      case key
+      when :provisioner
+        namespace_array!(sdata, :run_list, :suite)
+      when :lifecycle
+        sdata.each_key do |k|
+          namespace_array!(sdata, k, :suite)
+        end
+      end
       sdata
     end
 
@@ -923,7 +984,7 @@ module Kitchen
     #   Hash if not found
     # @api private
     def platform_data_for(name)
-      data.fetch(:platforms, Hash.new).find(-> { Hash.new }) do |platform|
+      data.fetch(:platforms, {}).find(-> { Hash.new }) do |platform|
         platform.fetch(:name, nil) == name
       end
     end
@@ -939,7 +1000,7 @@ module Kitchen
     # @param key [Symbol] the key to search for
     # @api private
     def set_kitchen_config_at!(root, key)
-      kdata = data.fetch(:kitchen, Hash.new)
+      kdata = data.fetch(:kitchen, {})
 
       root.delete(key) if root.key?(key)
       root[key] = kitchen_config.fetch(key) if kitchen_config.key?(key)
@@ -954,7 +1015,7 @@ module Kitchen
     #   Hash if not found
     # @api private
     def suite_data_for(name)
-      data.fetch(:suites, Hash.new).find(-> { Hash.new }) do |suite|
+      data.fetch(:suites, {}).find(-> { Hash.new }) do |suite|
         suite.fetch(:name, nil) == name
       end
     end
