@@ -20,18 +20,15 @@ require "benchmark"
 require "fileutils"
 
 module Kitchen
-
   # An instance of a suite running on a platform. A created instance may be a
   # local virtual machine, cloud instance, container, or even a bare metal
   # server, which is determined by the platform's driver.
   #
   # @author Fletcher Nichol <fnichol@nichol.ca>
   class Instance
-
     include Logging
 
     class << self
-
       # @return [Hash] a hash of mutxes, arranged by Driver class names
       # @api private
       attr_accessor :mutexes
@@ -42,7 +39,7 @@ module Kitchen
       # @param platform [Platform,#name] a Platform
       # @return [String] a normalized, consistent name for an instance
       def name_for(suite, platform)
-        "#{suite.name}-#{platform.name}".gsub(%r{[_,/]}, "-").gsub(/\./, "")
+        "#{suite.name}-#{platform.name}".gsub(%r{[_,/]}, "-").delete(".")
       end
     end
 
@@ -57,20 +54,23 @@ module Kitchen
 
     # @return [Driver::Base] driver object which will manage this instance's
     #   lifecycle actions
-    attr_reader :driver
+    attr_accessor :driver
+
+    # @return [LifecycleHooks] lifecycle hooks manager object
+    attr_accessor :lifecycle_hooks
 
     # @return [Provisioner::Base] provisioner object which will the setup
     #   and invocation instructions for configuration management and other
     #   automation tools
-    attr_reader :provisioner
+    attr_accessor :provisioner
 
     # @return [Transport::Base] transport object which will communicate with
     #   an instance.
-    attr_reader :transport
+    attr_accessor :transport
 
     # @return [Verifier] verifier object for instance to manage the verifier
     #   installation on this instance
-    attr_reader :verifier
+    attr_accessor :verifier
 
     # @return [Logger] the logger for this instance
     attr_reader :logger
@@ -93,20 +93,22 @@ module Kitchen
     def initialize(options = {})
       validate_options(options)
 
-      @suite        = options.fetch(:suite)
-      @platform     = options.fetch(:platform)
-      @name         = self.class.name_for(@suite, @platform)
-      @driver       = options.fetch(:driver)
-      @provisioner  = options.fetch(:provisioner)
-      @transport    = options.fetch(:transport)
-      @verifier     = options.fetch(:verifier)
-      @logger       = options.fetch(:logger) { Kitchen.logger }
-      @state_file   = options.fetch(:state_file)
+      @suite           = options.fetch(:suite)
+      @platform        = options.fetch(:platform)
+      @name            = self.class.name_for(@suite, @platform)
+      @driver          = options.fetch(:driver)
+      @lifecycle_hooks = options.fetch(:lifecycle_hooks)
+      @provisioner     = options.fetch(:provisioner)
+      @transport       = options.fetch(:transport)
+      @verifier        = options.fetch(:verifier)
+      @logger          = options.fetch(:logger) { Kitchen.logger }
+      @state_file      = options.fetch(:state_file)
 
       setup_driver
       setup_provisioner
       setup_transport
       setup_verifier
+      setup_lifecycle_hooks
     end
 
     # Returns a displayable representation of the instance.
@@ -210,12 +212,12 @@ module Kitchen
       end
 
       lc = if legacy_ssh_base_driver?
-        legacy_ssh_base_login(state)
-      else
-        transport.connection(state).login_command
-      end
+             legacy_ssh_base_login(state)
+           else
+             transport.connection(state).login_command
+           end
 
-      debug(%{Login command: #{lc.command} #{lc.arguments.join(" ")} } \
+      debug(%{Login command: #{lc.command} #{lc.arguments.join(' ')} } \
         "(Options: #{lc.options})")
       Kernel.exec(*lc.exec_args)
     end
@@ -229,11 +231,27 @@ module Kitchen
       end
     end
 
+    # Perform package.
+    #
+    def package_action
+      banner "Packaging remote instance"
+      driver.package(state_file.read)
+    end
+
+    # Check system and configuration for common errors.
+    #
+    def doctor_action
+      banner "The doctor is in"
+      [driver, provisioner, transport, verifier].any? do |obj|
+        obj.doctor(state_file.read)
+      end
+    end
+
     # Returns a Hash of configuration and other useful diagnostic information.
     #
     # @return [Hash] a diagnostic hash
     def diagnose
-      result = Hash.new
+      result = {}
       [
         :platform, :state_file, :driver, :provisioner, :transport, :verifier
       ].each do |sym|
@@ -248,14 +266,14 @@ module Kitchen
     #
     # @return [Hash] a diagnostic hash
     def diagnose_plugins
-      result = Hash.new
+      result = {}
       [:driver, :provisioner, :verifier, :transport].each do |sym|
         obj = send(sym)
         result[sym] = if obj.respond_to?(:diagnose_plugin)
-          obj.diagnose_plugin
-        else
-          :unknown
-        end
+                        obj.diagnose_plugin
+                      else
+                        :unknown
+                      end
       end
       result
     end
@@ -267,6 +285,13 @@ module Kitchen
       state_file.read[:last_action]
     end
 
+    # Returns the error encountered on the last action on the instance
+    #
+    # @return [String] the message of the last error
+    def last_error
+      state_file.read[:last_error]
+    end
+
     # Clean up any per-instance resources before exiting.
     #
     # @return [void]
@@ -307,12 +332,20 @@ module Kitchen
 
       if driver.class.serial_actions
         Kitchen.mutex.synchronize do
-          self.class.mutexes ||= Hash.new
+          self.class.mutexes ||= {}
           self.class.mutexes[driver.class] = Mutex.new
         end
       end
     end
 
+    # Perform any final configuration or preparation needed for the lifecycle hooks
+    # object carry out its duties.
+    #
+    # @api private
+    def setup_lifecycle_hooks
+      lifecycle_hooks.finalize_config!(self)
+    end
+
     # Perform any final configuration or preparation needed for the provisioner
     # object carry out its duties.
     #
@@ -345,7 +378,9 @@ module Kitchen
     def transition_to(desired)
       result = nil
       FSM.actions(last_action, desired).each do |transition|
-        result = send("#{transition}_action")
+        @lifecycle_hooks.run_with_hooks(transition, state_file) do
+          result = send("#{transition}_action")
+        end
       end
       result
     end
@@ -478,16 +513,19 @@ module Kitchen
         synchronize_or_call(what, state, &block)
       end
       state[:last_action] = what.to_s
+      state[:last_error] = nil
       elapsed
     rescue ActionFailed => e
       log_failure(what, e)
+      state[:last_error] = e.class.name
       raise(InstanceFailure, failure_message(what) +
         "  Please see .kitchen/logs/#{name}.log for more details",
-        e.backtrace)
+            e.backtrace)
     rescue Exception => e # rubocop:disable Lint/RescueException
       log_failure(what, e)
+      state[:last_error] = e.class.name
       raise ActionFailed,
-        "Failed to complete ##{what} action: [#{e.message}]", e.backtrace
+            "Failed to complete ##{what} action: [#{e.message}]", e.backtrace
     ensure
       state_file.write(state)
     end
@@ -502,15 +540,15 @@ module Kitchen
     # @param state [Hash] a mutable state hash for this instance
     # @param block [Proc] a block to be called
     # @api private
-    def synchronize_or_call(what, state, &block)
+    def synchronize_or_call(what, state)
       if Array(driver.class.serial_actions).include?(what)
         debug("#{to_str} is synchronizing on #{driver.class}##{what}")
         self.class.mutexes[driver.class].synchronize do
           debug("#{to_str} is messaging #{driver.class}##{what}")
-          block.call(state)
+          yield(state)
         end
       else
-        block.call(state)
+        yield(state)
       end
     end
 
@@ -622,7 +660,6 @@ module Kitchen
     # @api private
     # @author Fletcher Nichol <fnichol@nichol.ca>
     class FSM
-
       # Returns an Array of all transitions to bring an Instance from its last
       # reported transistioned state into the desired transitioned state.
       #
@@ -643,7 +680,7 @@ module Kitchen
         end
       end
 
-      TRANSITIONS = [:destroy, :create, :converge, :setup, :verify]
+      TRANSITIONS = [:destroy, :create, :converge, :setup, :verify].freeze
 
       # Determines the index of a state in the state lifecycle vector. Woah.
       #
