@@ -18,16 +18,16 @@
 
 require "kitchen"
 
+require "fileutils"
 require "net/ssh"
 require "net/ssh/gateway"
+require "net/ssh/proxy/http"
 require "net/scp"
 require "timeout"
 require "benchmark"
 
 module Kitchen
-
   module Transport
-
     # Wrapped exception for any internally raised SSH-related errors.
     #
     # @author Fletcher Nichol <fnichol@nichol.ca>
@@ -38,7 +38,6 @@ module Kitchen
     #
     # @author Fletcher Nichol <fnichol@nichol.ca>
     class Ssh < Kitchen::Transport::Base
-
       kitchen_transport_api_version 1
 
       plugin_version Kitchen::VERSION
@@ -55,8 +54,14 @@ module Kitchen
       default_config :max_wait_until_ready, 600
 
       default_config :ssh_gateway, nil
+      default_config :ssh_gateway_port, 22
       default_config :ssh_gateway_username, nil
 
+      default_config :ssh_http_proxy, nil
+      default_config :ssh_http_proxy_port, nil
+      default_config :ssh_http_proxy_user, nil
+      default_config :ssh_http_proxy_password, nil
+
       default_config :ssh_key, nil
       expand_path_for :ssh_key
 
@@ -110,6 +115,11 @@ module Kitchen
       #
       # @author Fletcher Nichol <fnichol@nichol.ca>
       class Connection < Kitchen::Transport::Base::Connection
+        # (see Base::Connection#initialize)
+        def initialize(config = {})
+          super(config)
+          @session = nil
+        end
 
         # (see Base::Connection#close)
         def close
@@ -139,21 +149,20 @@ module Kitchen
 
         # (see Base::Connection#login_command)
         def login_command
-          args  = %W[ -o UserKnownHostsFile=/dev/null ]
-          args += %W[ -o StrictHostKeyChecking=no ]
-          args += %W[ -o IdentitiesOnly=yes ] if options[:keys]
-          args += %W[ -o LogLevel=#{logger.debug? ? "VERBOSE" : "ERROR"} ]
+          args  = %w{ -o UserKnownHostsFile=/dev/null }
+          args += %w{ -o StrictHostKeyChecking=no }
+          args += %w{ -o IdentitiesOnly=yes } if options[:keys]
+          args += %W{ -o LogLevel=#{logger.debug? ? 'VERBOSE' : 'ERROR'} }
           if options.key?(:forward_agent)
-            args += %W[ -o ForwardAgent=#{options[:forward_agent] ? "yes" : "no"} ]
+            args += %W{ -o ForwardAgent=#{options[:forward_agent] ? 'yes' : 'no'} }
           end
           if ssh_gateway
             gateway_command = "ssh -q #{ssh_gateway_username}@#{ssh_gateway} nc #{hostname} #{port}"
-            # Should support other ports than 22 for ssh gateways
-            args += %W[ -o ProxyCommand=#{gateway_command} -p 22 ]
+            args += %W{ -o ProxyCommand=#{gateway_command} -p #{ssh_gateway_port} }
           end
-          Array(options[:keys]).each { |ssh_key| args += %W[ -i #{ssh_key} ] }
-          args += %W[ -p #{port} ]
-          args += %W[ #{username}@#{hostname} ]
+          Array(options[:keys]).each { |ssh_key| args += %W{ -i #{ssh_key} } }
+          args += %W{ -p #{port} }
+          args += %W{ #{username}@#{hostname} }
 
           LoginCommand.new("ssh", args)
         end
@@ -164,7 +173,7 @@ module Kitchen
           elapsed = Benchmark.measure do
             waits = []
             Array(locals).map do |local|
-              opts = File.directory?(local) ? { :recursive => true } : {}
+              opts = File.directory?(local) ? { recursive: true } : {}
 
               waits.push session.scp.upload(local, remote, opts) do |_ch, name, sent, total|
                 logger.debug("Async Uploaded #{name} (#{total} bytes)") if sent == total
@@ -179,13 +188,37 @@ module Kitchen
           raise SshFailed, "SCP upload failed (#{ex.message})"
         end
 
+        # (see Base::Connection#download)
+        def download(remotes, local)
+          # ensure the parent dir of the local target exists
+          FileUtils.mkdir_p(File.dirname(local))
+
+          Array(remotes).each do |file|
+            begin
+              logger.debug("Attempting to download '#{file}' as file")
+              session.scp.download!(file, local)
+            rescue Net::SCP::Error
+              begin
+                logger.debug("Attempting to download '#{file}' as directory")
+                session.scp.download!(file, local, recursive: true)
+              rescue Net::SCP::Error
+                logger.warn(
+                  "SCP download failed for file or directory '#{file}', perhaps it does not exist?"
+                )
+              end
+            end
+          end
+        rescue Net::SSH::Exception => ex
+          raise SshFailed, "SCP download failed (#{ex.message})"
+        end
+
         # (see Base::Connection#wait_until_ready)
         def wait_until_ready
           delay = 3
           session(
-            :retries  => max_wait_until_ready / delay,
-            :delay    => delay,
-            :message  => "Waiting for SSH service on #{hostname}:#{port}, " \
+            retries: max_wait_until_ready / delay,
+            delay: delay,
+            message: "Waiting for SSH service on #{hostname}:#{port}, " \
               "retrying in #{delay} seconds"
           )
           execute(PING_COMMAND.dup)
@@ -196,8 +229,8 @@ module Kitchen
         PING_COMMAND = "echo '[SSH] Established'".freeze
 
         RESCUE_EXCEPTIONS_ON_ESTABLISH = [
-          Errno::EACCES, Errno::EADDRINUSE, Errno::ECONNREFUSED, Errno::ETIMEDOUT,
-          Errno::ECONNRESET, Errno::ENETUNREACH, Errno::EHOSTUNREACH,
+          Errno::EACCES, Errno::EALREADY, Errno::EADDRINUSE, Errno::ECONNREFUSED, Errno::ETIMEDOUT,
+          Errno::ECONNRESET, Errno::ENETUNREACH, Errno::EHOSTUNREACH, Errno::EPIPE,
           Net::SSH::Disconnect, Net::SSH::AuthenticationFailed, Net::SSH::ConnectionTimeout,
           Timeout::Error
         ].freeze
@@ -244,6 +277,30 @@ module Kitchen
         # @api private
         attr_reader :ssh_gateway_username
 
+        # @return [Integer] The port to use when using an ssh gateway
+        # @api private
+        attr_reader :ssh_gateway_port
+
+        # @return [String] The kitchen ssh proxy to use when connecting to the
+        #   remote SSH host via http proxy
+        # @api private
+        attr_reader :ssh_http_proxy
+
+        # @return [Integer] The port to use when using an kitchen ssh proxy
+        #   remote SSH host via http proxy
+        # @api private
+        attr_reader :ssh_http_proxy_port
+
+        # @return [String] The username to use when using an kitchen ssh proxy
+        #   remote SSH host via http proxy
+        # @api private
+        attr_reader :ssh_http_proxy_user
+
+        # @return [String] The password to use when using an kitchen ssh proxy
+        #   remote SSH host via http proxy
+        # @api private
+        attr_reader :ssh_http_proxy_password
+
         # Establish an SSH session on the remote host using a gateway host.
         #
         # @param opts [Hash] retry options
@@ -257,8 +314,9 @@ module Kitchen
         # @api private
         def establish_connection_via_gateway(opts)
           retry_connection(opts) do
+            gateway_options = options.merge(:port => ssh_gateway_port)
             Net::SSH::Gateway.new(ssh_gateway,
-              ssh_gateway_username, options).ssh(hostname, username, options)
+                                  ssh_gateway_username, gateway_options).ssh(hostname, username, options)
           end
         end
 
@@ -292,18 +350,18 @@ module Kitchen
         # @api private
         def retry_connection(opts)
           log_msg = "[SSH] opening connection to #{self}"
-          log_msg += " via #{ssh_gateway_username}@#{ssh_gateway}" if ssh_gateway
+          log_msg += " via #{ssh_gateway_username}@#{ssh_gateway}:#{ssh_gateway_port}" if ssh_gateway
           logger.debug(log_msg)
           yield
         rescue *RESCUE_EXCEPTIONS_ON_ESTABLISH => e
           if (opts[:retries] -= 1) > 0
             message = if opts[:message]
-              logger.debug("[SSH] connection failed (#{e.inspect})")
-              opts[:message]
-            else
-              "[SSH] connection failed, retrying in #{opts[:delay]} seconds " \
-                "(#{e.inspect})"
-            end
+                        logger.debug("[SSH] connection failed (#{e.inspect})")
+                        opts[:message]
+                      else
+                        "[SSH] connection failed, retrying in #{opts[:delay]} seconds " \
+                          "(#{e.inspect})"
+                      end
             logger.info(message)
             sleep(opts[:delay])
             retry
@@ -321,11 +379,9 @@ module Kitchen
         def execute_with_exit_code(command)
           exit_code = nil
           session.open_channel do |channel|
-
             channel.request_pty
 
             channel.exec(command) do |_ch, _success|
-
               channel.on_data do |_ch, data|
                 logger << data
               end
@@ -346,15 +402,20 @@ module Kitchen
         # (see Base::Connection#init_options)
         def init_options(options)
           super
-          @username               = @options.delete(:username)
-          @hostname               = @options.delete(:hostname)
-          @port                   = @options[:port] # don't delete from options
-          @connection_retries     = @options.delete(:connection_retries)
-          @connection_retry_sleep = @options.delete(:connection_retry_sleep)
-          @max_ssh_sessions       = @options.delete(:max_ssh_sessions)
-          @max_wait_until_ready   = @options.delete(:max_wait_until_ready)
-          @ssh_gateway            = @options.delete(:ssh_gateway)
-          @ssh_gateway_username   = @options.delete(:ssh_gateway_username)
+          @username                = @options.delete(:username)
+          @hostname                = @options.delete(:hostname)
+          @port                    = @options[:port] # don't delete from options
+          @connection_retries      = @options.delete(:connection_retries)
+          @connection_retry_sleep  = @options.delete(:connection_retry_sleep)
+          @max_ssh_sessions        = @options.delete(:max_ssh_sessions)
+          @max_wait_until_ready    = @options.delete(:max_wait_until_ready)
+          @ssh_gateway             = @options.delete(:ssh_gateway)
+          @ssh_gateway_username    = @options.delete(:ssh_gateway_username)
+          @ssh_gateway_port        = @options.delete(:ssh_gateway_port)
+          @ssh_http_proxy          = @options.delete(:ssh_http_proxy)
+          @ssh_http_proxy_user     = @options.delete(:ssh_http_proxy_user)
+          @ssh_http_proxy_password = @options.delete(:ssh_http_proxy_password)
+          @ssh_http_proxy_port     = @options.delete(:ssh_http_proxy_port)
         end
 
         # Returns a connection session, or establishes one when invoked the
@@ -366,13 +427,13 @@ module Kitchen
         def session(retry_options = {})
           if ssh_gateway
             @session ||= establish_connection_via_gateway({
-              :retries => connection_retries.to_i,
-              :delay   => connection_retry_sleep.to_i
+              retries: connection_retries.to_i,
+              delay: connection_retry_sleep.to_i,
             }.merge(retry_options))
           else
             @session ||= establish_connection({
-              :retries => connection_retries.to_i,
-              :delay   => connection_retry_sleep.to_i
+              retries: connection_retries.to_i,
+              delay: connection_retry_sleep.to_i,
             }.merge(retry_options))
           end
         end
@@ -394,26 +455,26 @@ module Kitchen
       # @param data [Hash] merged configuration and mutable state data
       # @return [Hash] hash of connection options
       # @api private
-      # rubocop:disable Metrics/MethodLength, Metrics/AbcSize, Metrics/CyclomaticComplexity
+      # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
       def connection_options(data)
         opts = {
-          :logger                 => logger,
-          :user_known_hosts_file  => "/dev/null",
-          :paranoid               => false,
-          :hostname               => data[:hostname],
-          :port                   => data[:port],
-          :username               => data[:username],
-          :compression            => data[:compression],
-          :compression_level      => data[:compression_level],
-          :keepalive              => data[:keepalive],
-          :keepalive_interval     => data[:keepalive_interval],
-          :timeout                => data[:connection_timeout],
-          :connection_retries     => data[:connection_retries],
-          :connection_retry_sleep => data[:connection_retry_sleep],
-          :max_ssh_sessions       => data[:max_ssh_sessions],
-          :max_wait_until_ready   => data[:max_wait_until_ready],
-          :ssh_gateway            => data[:ssh_gateway],
-          :ssh_gateway_username   => data[:ssh_gateway_username]
+          logger: logger,
+          user_known_hosts_file: "/dev/null",
+          hostname: data[:hostname],
+          port: data[:port],
+          username: data[:username],
+          compression: data[:compression],
+          compression_level: data[:compression_level],
+          keepalive: data[:keepalive],
+          keepalive_interval: data[:keepalive_interval],
+          timeout: data[:connection_timeout],
+          connection_retries: data[:connection_retries],
+          connection_retry_sleep: data[:connection_retry_sleep],
+          max_ssh_sessions: data[:max_ssh_sessions],
+          max_wait_until_ready: data[:max_wait_until_ready],
+          ssh_gateway: data[:ssh_gateway],
+          ssh_gateway_username: data[:ssh_gateway_username],
+          ssh_gateway_port: data[:ssh_gateway_port],
         }
 
         if data[:ssh_key] && !data[:password]
@@ -422,13 +483,47 @@ module Kitchen
           opts[:auth_methods] = ["publickey"]
         end
 
+        if data[:ssh_http_proxy]
+          options_http_proxy = {}
+          options_http_proxy[:user] = data[:ssh_http_proxy_user]
+          options_http_proxy[:password] = data[:ssh_http_proxy_password]
+          opts[:proxy] = Net::SSH::Proxy::HTTP.new(data[:ssh_http_proxy], data[:ssh_http_proxy_port], options_http_proxy)
+        end
+
+        if data[:ssh_key_only]
+          opts[:auth_methods] = ["publickey"]
+        end
+
         opts[:password] = data[:password]           if data.key?(:password)
         opts[:forward_agent] = data[:forward_agent] if data.key?(:forward_agent)
         opts[:verbose] = data[:verbose].to_sym      if data.key?(:verbose)
 
+        # disable host key verification. The hash key to use
+        # depends on the version of net-ssh in use.
+        opts[verify_host_key_option] = false
+
         opts
       end
 
+      #
+      # Returns the correct host-key-verification option key to use depending
+      # on what version of net-ssh is in use. In net-ssh <= 4.1, the supported
+      # parameter is `paranoid` but in 4.2, it became `verify_host_key`
+      #
+      # `verify_host_key` does not work in <= 4.1, and `paranoid` throws
+      # deprecation warnings in >= 4.2.
+      #
+      # While the "right thing" to do would be to pin train's dependency on
+      # net-ssh to ~> 4.2, this will prevent InSpec from being used in
+      # Chef v12 because of it pinning to a v3 of net-ssh.
+      #
+      def verify_host_key_option
+        current_net_ssh = Net::SSH::Version::CURRENT
+        new_option_version = Net::SSH::Version[4, 2, 0]
+
+        current_net_ssh >= new_option_version ? :verify_host_key : :paranoid
+      end
+
       # Creates a new SSH Connection instance and save it for potential future
       # reuse.
       #
