@@ -23,11 +23,8 @@ require "kitchen/transport/ssh"
 require "kitchen/verifier/busser"
 
 module Kitchen
-
   module Driver
-
     class BackCompat < Kitchen::Driver::SSHBase
-
       def use_run_remote(state, command)
         connection = Kitchen::SSH.new(*build_ssh_args(state))
         run_remote(command, connection)
@@ -43,12 +40,10 @@ module Kitchen
     end
 
     class DodgyCompat < Kitchen::Driver::SSHBase
-
       no_parallel_for :converge
     end
 
     class SlowCompat < Kitchen::Driver::SSHBase
-
       no_parallel_for :create, :destroy
       no_parallel_for :verify
     end
@@ -56,7 +51,6 @@ module Kitchen
 end
 
 describe Kitchen::Driver::SSHBase do
-
   let(:logged_output) { StringIO.new }
   let(:logger)        { Logger.new(logged_output) }
   let(:config)        { Hash.new }
@@ -78,13 +72,13 @@ describe Kitchen::Driver::SSHBase do
 
   let(:provisioner) do
     stub(
-      :install_command  => "install",
-      :init_command     => "init",
-      :prepare_command  => "prepare",
-      :run_command      => "run",
-      :create_sandbox   => true,
-      :cleanup_sandbox  => true,
-      :sandbox_path     => "/tmp/sandbox"
+      install_command: "install",
+      init_command: "init",
+      prepare_command: "prepare",
+      run_command: "run",
+      create_sandbox: true,
+      cleanup_sandbox: true,
+      sandbox_path: "/tmp/sandbox"
     )
   end
 
@@ -96,12 +90,12 @@ describe Kitchen::Driver::SSHBase do
 
   let(:instance) do
     stub(
-      :name         => "coolbeans",
-      :logger       => logger,
-      :verifier     => verifier,
-      :provisioner  => provisioner,
-      :transport    => transport,
-      :to_str       => "instance"
+      name: "coolbeans",
+      logger: logger,
+      verifier: verifier,
+      provisioner: provisioner,
+      transport: transport,
+      to_str: "instance"
     )
   end
 
@@ -110,11 +104,10 @@ describe Kitchen::Driver::SSHBase do
   end
 
   it "plugin_version is not set" do
-    driver.diagnose_plugin[:version].must_equal nil
+    driver.diagnose_plugin[:version].must_be_nil
   end
 
   describe "configuration" do
-
     it ":sudo defaults to true" do
       driver[:sudo].must_equal true
     end
@@ -135,19 +128,18 @@ describe Kitchen::Driver::SSHBase do
   # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
   def self.constructs_an_ssh_connection
     describe "constructs an SSH connection" do
-
       it "with hostname set from state" do
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:hostname].must_equal "fizzy"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
 
       it "with username set from state" do
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:username].must_equal "bork"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -155,9 +147,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :ssh_key option set from config" do
         config[:ssh_key] = "wicked"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:ssh_key].must_equal "wicked"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -165,17 +157,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :ssh_key option set from state" do
         state[:ssh_key] = "wicked"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:ssh_key].must_equal "wicked"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
 
       it "with :password option set to falsey by default" do
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:password].nil?
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -183,9 +175,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :password option set if given in config" do
         config[:password] = "psst"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:password].must_equal "psst"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -193,17 +185,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :password option set if given in state" do
         state[:password] = "psst"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:password].must_equal "psst"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
 
       it "with :forward_agent option set to falsey by default" do
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:forward_agent].nil?
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -211,9 +203,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :forward_agent option set if given in config" do
         config[:forward_agent] = "yeah?"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:forward_agent].must_equal "yeah?"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -221,17 +213,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :forward_agent option set if given in state" do
         state[:forward_agent] = "yeah?"
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:forward_agent].must_equal "yeah?"
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
 
       it "with :port option set to 22 by default" do
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:port].must_equal 22
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -239,9 +231,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :port option set if customized in config" do
         config[:port] = 1234
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:port].must_equal 1234
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -249,9 +241,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :port option set if customized in state" do
         state[:port] = 9999
 
-        transport.expects(:connection).with { |state|
+        transport.expects(:connection).with do |state|
           state[:port].must_equal 9999
-        }.returns(stub(:login_command => stub))
+        end.returns(stub(login_command: stub))
 
         cmd
       end
@@ -260,7 +252,6 @@ describe Kitchen::Driver::SSHBase do
   # rubocop:enable Metrics/MethodLength, Metrics/AbcSize
 
   describe "#login_command" do
-
     let(:cmd) { driver.login_command(state) }
 
     before do
@@ -269,7 +260,7 @@ describe Kitchen::Driver::SSHBase do
     end
 
     it "returns a LoginCommand" do
-      transport.stubs(:connection).returns(stub(:login_command => "command"))
+      transport.stubs(:connection).returns(stub(login_command: "command"))
 
       cmd.must_equal "command"
     end
@@ -278,14 +269,17 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#converge" do
-
     let(:cmd)         { driver.converge(state) }
-    let(:connection)  { stub(:execute => true, :upload => true) }
+    let(:connection)  { stub(execute: true, upload: true, download: true) }
 
     before do
       state[:hostname] = "fizzy"
       state[:username] = "bork"
       provisioner.stubs(:[]).with(:root_path).returns("/rooty")
+      provisioner.stubs(:[]).with(:downloads).returns(
+        ["/tmp/kitchen/nodes", "/tmp/kitchen/data_bags"] => "./test/fixtures",
+        "/remote" => "/local"
+      )
       FakeFS.activate!
       FileUtils.mkdir_p("/tmp")
       @original_env = ENV.to_hash
@@ -340,25 +334,25 @@ describe Kitchen::Driver::SSHBase do
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"http_proxy\"] set" do
+    it 'invokes the #install_command with ENV["http_proxy"] set' do
       ENV["http_proxy"] = "http://proxy"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env http_proxy=http://proxy HTTP_PROXY=http://proxy install")
+        connection.expects(:execute)
+                  .with("env http_proxy=http://proxy HTTP_PROXY=http://proxy install")
       else
         connection.expects(:execute).with("env http_proxy=http://proxy install")
       end
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"http_proxy\"] and ENV[\"no_proxy\"] set" do
+    it 'invokes the #install_command with ENV["http_proxy"] and ENV["no_proxy"] set' do
       ENV["http_proxy"] = "http://proxy"
       ENV["no_proxy"]   = "http://no"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env http_proxy=http://proxy HTTP_PROXY=http://proxy " \
+        connection.expects(:execute)
+                  .with("env http_proxy=http://proxy HTTP_PROXY=http://proxy " \
             "no_proxy=http://no NO_PROXY=http://no install")
       else
         connection.expects(:execute).with("env http_proxy=http://proxy " \
@@ -375,25 +369,25 @@ describe Kitchen::Driver::SSHBase do
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"https_proxy\"] set" do
+    it 'invokes the #install_command with ENV["https_proxy"] set' do
       ENV["https_proxy"] = "https://proxy"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env https_proxy=https://proxy HTTPS_PROXY=https://proxy install")
+        connection.expects(:execute)
+                  .with("env https_proxy=https://proxy HTTPS_PROXY=https://proxy install")
       else
         connection.expects(:execute).with("env https_proxy=https://proxy install")
       end
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"https_proxy\"] and ENV[\"no_proxy\"] set" do
+    it 'invokes the #install_command with ENV["https_proxy"] and ENV["no_proxy"] set' do
       ENV["https_proxy"] = "https://proxy"
       ENV["no_proxy"]    = "https://no"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env https_proxy=https://proxy HTTPS_PROXY=https://proxy " \
+        connection.expects(:execute)
+                  .with("env https_proxy=https://proxy HTTPS_PROXY=https://proxy " \
           "no_proxy=https://no NO_PROXY=https://no install")
       else
         connection.expects(:execute).with("env https_proxy=https://proxy " \
@@ -410,25 +404,25 @@ describe Kitchen::Driver::SSHBase do
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"ftp_proxy\"] set" do
+    it 'invokes the #install_command with ENV["ftp_proxy"] set' do
       ENV["ftp_proxy"] = "ftp://proxy"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env ftp_proxy=ftp://proxy FTP_PROXY=ftp://proxy install")
+        connection.expects(:execute)
+                  .with("env ftp_proxy=ftp://proxy FTP_PROXY=ftp://proxy install")
       else
         connection.expects(:execute).with("env ftp_proxy=ftp://proxy install")
       end
       cmd
     end
 
-    it "invokes the #install_command with ENV[\"ftp_proxy\"] and ENV[\"no_proxy\"] set" do
+    it 'invokes the #install_command with ENV["ftp_proxy"] and ENV["no_proxy"] set' do
       ENV["ftp_proxy"]  = "ftp://proxy"
       ENV["no_proxy"]   = "http://no"
       transport.stubs(:connection).yields(connection)
       if running_tests_on_windows?
-        connection.expects(:execute).
-          with("env ftp_proxy=ftp://proxy FTP_PROXY=http://proxy " \
+        connection.expects(:execute)
+                  .with("env ftp_proxy=ftp://proxy FTP_PROXY=http://proxy " \
             "no_proxy=http://no NO_PROXY=http://no install")
       else
         connection.expects(:execute).with("env ftp_proxy=ftp://proxy " \
@@ -449,7 +443,6 @@ describe Kitchen::Driver::SSHBase do
     end
 
     describe "transferring files" do
-
       before do
         transport.stubs(:connection).yields(connection)
         connection.stubs(:upload)
@@ -465,8 +458,8 @@ describe Kitchen::Driver::SSHBase do
       it "logs to info" do
         cmd
 
-        logged_output.string.
-          must_match(/INFO -- : Transferring files to instance$/)
+        logged_output.string
+                     .must_match(/INFO -- : Transferring files to instance$/)
       end
 
       it "logs to debug" do
@@ -482,6 +475,43 @@ describe Kitchen::Driver::SSHBase do
       end
     end
 
+    describe "downloading files" do
+      before do
+        transport.stubs(:connection).yields(connection)
+        connection.stubs(:download)
+      end
+
+      it "downloads files" do
+        connection.expects(:download).with(
+          ["/tmp/kitchen/nodes", "/tmp/kitchen/data_bags"],
+          "./test/fixtures"
+        )
+        connection.expects(:download).with("/remote", "/local")
+
+        cmd
+      end
+
+      it "logs to info" do
+        cmd
+
+        logged_output.string.must_match(
+          /INFO -- : Downloading files from instance$/
+        )
+      end
+
+      it "logs to debug" do
+        cmd
+
+        logged_output.string.must_match(
+          %r{DEBUG -- : Downloading /tmp/kitchen/nodes, /tmp/kitchen/data_bags to ./test/fixtures$}
+        )
+        logged_output.string.must_match(
+          %r{DEBUG -- : Downloading /remote to /local$}
+        )
+        logged_output.string.must_match(/DEBUG -- : Download complete$/)
+      end
+    end
+
     it "raises an ActionFailed on execute when SshFailed is raised" do
       transport.stubs(:connection).yields(connection)
       connection.stubs(:execute).raises(Kitchen::Transport::SshFailed.new("dang"))
@@ -491,7 +521,6 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#setup" do
-
     let(:cmd)         { driver.setup(state) }
     let(:connection)  { mock }
 
@@ -553,9 +582,8 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#verify" do
-
     let(:cmd)         { driver.verify(state) }
-    let(:connection)  { stub(:execute => true, :upload => true) }
+    let(:connection)  { stub(execute: true, upload: true) }
 
     before do
       state[:hostname] = "fizzy"
@@ -590,7 +618,7 @@ describe Kitchen::Driver::SSHBase do
       cmd
     end
 
-    %W[init prepare run].each do |phase|
+    %w{init prepare run}.each do |phase|
       it "invokes Verifier##{phase}_command over ssh" do
         connection.expects(:execute).with(phase)
 
@@ -632,8 +660,8 @@ describe Kitchen::Driver::SSHBase do
     it "logs to info" do
       cmd
 
-      logged_output.string.
-        must_match(/INFO -- : Transferring files to instance$/)
+      logged_output.string
+                   .must_match(/INFO -- : Transferring files to instance$/)
     end
 
     it "uploads sandbox files" do
@@ -649,8 +677,8 @@ describe Kitchen::Driver::SSHBase do
     end
 
     it "raises an ActionFailed on transfer when TransportFailed is raised" do
-      connection.stubs(:upload).
-        raises(Kitchen::Transport::TransportFailed.new("dang"))
+      connection.stubs(:upload)
+                .raises(Kitchen::Transport::TransportFailed.new("dang"))
 
       proc { cmd }.must_raise Kitchen::ActionFailed
     end
@@ -663,17 +691,16 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#ssh" do
-
-    let(:cmd)         { driver.ssh(["host", "user", { :one => "two" }], "go") }
+    let(:cmd)         { driver.ssh(["host", "user", { one: "two" }], "go") }
     let(:connection)  { mock }
 
     it "creates an SSH connection" do
       connection.stubs(:execute)
       transport.expects(:connection).with(
-        :hostname => "host",
-        :username => "user",
-        :port => 22,
-        :one => "two"
+        hostname: "host",
+        username: "user",
+        port: 22,
+        one: "two"
       ).yields(connection)
 
       cmd
@@ -688,7 +715,6 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#remote_command" do
-
     let(:cmd)         { driver.remote_command(state, "shipit") }
     let(:connection)  { mock }
 
@@ -699,9 +725,9 @@ describe Kitchen::Driver::SSHBase do
 
     it "creates an SSH connection" do
       transport.expects(:connection).with(
-        :hostname => "fizzy",
-        :username => "bork",
-        :port => 22
+        hostname: "fizzy",
+        username: "bork",
+        port: 22
       )
 
       cmd
@@ -716,18 +742,17 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "#wait_for_sshd" do
-
     let(:cmd) do
-      driver.send(:wait_for_sshd, "host", "user", :one => "two")
+      driver.send(:wait_for_sshd, "host", "user", one: "two")
     end
 
     it "creates an SSH connection with merged options" do
       transport.expects(:connection).with(
-        :hostname => "host",
-        :username => "user",
-        :port => 22,
-        :one => "two"
-      ).returns(stub(:wait_until_ready => true))
+        hostname: "host",
+        username: "user",
+        port: 22,
+        one: "two"
+      ).returns(stub(wait_until_ready: true))
 
       cmd
     end
@@ -742,7 +767,6 @@ describe Kitchen::Driver::SSHBase do
   end
 
   describe "to maintain backwards compatibility" do
-
     let(:driver) do
       Kitchen::Driver::BackCompat.new(config).finalize_config!(instance)
     end
@@ -756,7 +780,6 @@ describe Kitchen::Driver::SSHBase do
     end
 
     describe "#logger" do
-
       before  { @klog = Kitchen.logger }
       after   { Kitchen.logger = @klog }
 
@@ -795,9 +818,8 @@ describe Kitchen::Driver::SSHBase do
     end
 
     describe ".no_parallel_for" do
-
       it "registers no serial actions when none are declared" do
-        Kitchen::Driver::SpeedyCompat.serial_actions.must_equal nil
+        Kitchen::Driver::SpeedyCompat.serial_actions.must_be_nil
       end
 
       it "registers a single serial action method" do
@@ -813,52 +835,52 @@ describe Kitchen::Driver::SSHBase do
       end
 
       it "raises a ClientError if value is not an action method" do
-        proc {
-          Class.new(Kitchen::Driver::BackCompat) {
+        proc do
+          Class.new(Kitchen::Driver::BackCompat) do
             no_parallel_for :telling_stories
-          }
-        }.must_raise Kitchen::ClientError
+          end
+        end.must_raise Kitchen::ClientError
       end
     end
 
     # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
     def self.constructs_an_ssh_object
       it "with hostname set from state" do
-        Kitchen::SSH.expects(:new).with { |hostname, _username, _opts|
+        Kitchen::SSH.expects(:new).with do |hostname, _username, _opts|
           hostname.must_equal "fizzy"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with username set from state" do
-        Kitchen::SSH.expects(:new).with { |_hostname, username, _opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, username, _opts|
           username.must_equal "bork"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :user_known_hosts_file option set to /dev/null" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:user_known_hosts_file].must_equal "/dev/null"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
-      it "with :paranoid option set to false" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
-          opts[:paranoid].must_equal false
-        }.returns(connection)
+      it "with :verify_host_key option set to false" do
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
+          opts[:verify_host_key].must_equal false
+        end.returns(connection)
 
         cmd
       end
 
       it "with :keys_only option set to falsey by default" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys_only].nil?
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -866,9 +888,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :keys_only option set to true if :ssh_key is set in config" do
         config[:ssh_key] = "wicked"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys_only].must_equal true
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -876,17 +898,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :keys_only option set to true if :ssh_key is set in state" do
         state[:ssh_key] = "wicked"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys_only].must_equal true
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :keys option set to falsey by default" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys].nil?
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -894,9 +916,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :keys option set to an array if :ssh_key is set in config" do
         config[:ssh_key] = "wicked"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys].must_equal ["wicked"]
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -904,17 +926,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :keys option set to an array if :ssh_key is set in state" do
         state[:ssh_key] = "wicked"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:keys].must_equal ["wicked"]
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :password option set to falsey by default" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:password].nil?
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -922,9 +944,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :password option set if given in config" do
         config[:password] = "psst"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:password].must_equal "psst"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -932,17 +954,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :password option set if given in state" do
         state[:password] = "psst"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:password].must_equal "psst"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :forward_agent option set to falsey by default" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:forward_agent].nil?
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -950,9 +972,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :forward_agent option set if given in config" do
         config[:forward_agent] = "yeah?"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:forward_agent].must_equal "yeah?"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -960,17 +982,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :forward_agent option set if given in state" do
         state[:forward_agent] = "yeah?"
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:forward_agent].must_equal "yeah?"
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :port option set to 22 by default" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:port].must_equal 22
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -978,9 +1000,9 @@ describe Kitchen::Driver::SSHBase do
       it "with :port option set if customized in config" do
         config[:port] = 1234
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:port].must_equal 1234
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -988,17 +1010,17 @@ describe Kitchen::Driver::SSHBase do
       it "with :port option set if customized in state" do
         state[:port] = 9999
 
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:port].must_equal 9999
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
 
       it "with :logger option set to driver's logger" do
-        Kitchen::SSH.expects(:new).with { |_hostname, _username, opts|
+        Kitchen::SSH.expects(:new).with do |_hostname, _username, opts|
           opts[:logger].must_equal logger
-        }.returns(connection)
+        end.returns(connection)
 
         cmd
       end
@@ -1006,9 +1028,8 @@ describe Kitchen::Driver::SSHBase do
     # rubocop:enable Metrics/MethodLength, Metrics/AbcSize
 
     describe "#run_remote" do
-
       let(:cmd)         { driver.use_run_remote(state, "huh") }
-      let(:connection)  { stub(:exec => true) }
+      let(:connection)  { stub(exec: true) }
 
       before do
         state[:hostname] = "fizzy"
@@ -1074,10 +1095,9 @@ describe Kitchen::Driver::SSHBase do
     end
 
     describe "#transfer_path" do
-
       let(:cmd)         { driver.use_transfer_path(state, ["nope"], "nadda") }
-      let(:channel)     { stub(:wait => true) }
-      let(:connection)  { stub(:upload_path! => true, :upload_path => channel) }
+      let(:channel)     { stub(wait: true) }
+      let(:connection)  { stub(upload_path!: true, upload_path: channel) }
 
       before do
         state[:hostname] = "fizzy"
