@@ -19,114 +19,20 @@
 require_relative "../../spec_helper"
 
 require "kitchen/transport/ssh"
-
-# Hack to sort results in `Dir.entries` only within the yielded block, to limit
-# the "behavior pollution" to other code. This was needed for Net::SCP, as
-# recursive directory upload doesn't sort the file and directory upload
-# candidates which leads to different results based on the underlying
-# filesystem (i.e. lexically sorted, inode insertion, mtime/atime, total
-# randomness, etc.)
-#
-# See: https://github.com/net-ssh/net-scp/blob/a24948/lib/net/scp/upload.rb#L52
-
-def with_sorted_dir_entries
-  Dir.class_exec do
-    class << self
-      alias_method :__entries__, :entries unless method_defined?(:__entries__)
-
-      def entries(*args) # rubocop:disable Lint/NestedMethodDefinition
-        send(:__entries__, *args).sort
-      end
-    end
-  end
-
-  yield
-
-  Dir.class_exec do
-    class << self
-      alias_method :entries, :__entries__
-    end
-  end
-end
-
-# Terrible hack to deal with Net::SSH:Test::Extensions which monkey patches
-# `IO.select` with a version for testing Net::SSH code. Unfortunetly this
-# impacts other code, so we'll "un-patch" this after each spec and "re-patch"
-# it before the next one.
 require "net/ssh/test"
-def depatch_io
-  IO.class_exec do
-    class << self
-      alias_method :select, :select_for_real
-    end
-  end
-end
-# We need to immediately call depatch so that `IO.select` is in a good state
-# _right now_.  The require immediately monkeypatches it and we only want
-# it monkey patched inside each ssh test
-depatch_io
-
-def repatch_io
-  IO.class_exec do
-    class << self
-      alias_method :select, :select_for_test
-    end
-  end
-end
-
-# Major hack-and-a-half to add basic `Channel#request_pty` support to
-# Net::SSH's testing framework. The `Net::SSH::Test::LocalPacket` does not
-# recognize the `"pty-req"` request type, so bombs out whenever this channel
-# request is sent.
-#
-# This "make-work" fix adds a method (`#sends_request_pty`) which works just
-# like `#sends_exec` expcept that it enqueues a patched subclass of
-# `LocalPacket` which can deal with the `"pty-req"` type.
-#
-# An upstream patch to Net::SSH will be required to retire this yak shave ;)
-require "net/ssh/test/channel"
-module Net
-
-  module SSH
-
-    module Test
-
-      class Channel
-
-        def sends_request_pty
-          pty_data = ["xterm", 80, 24, 640, 480, "\0"]
-
-          script.events << Class.new(Net::SSH::Test::LocalPacket) do
-            def types # rubocop:disable Lint/NestedMethodDefinition
-              if @type == 98 && @data[1] == "pty-req"
-                @types ||= [
-                  :long, :string, :bool, :string,
-                  :long, :long, :long, :long, :string
-                ]
-              else
-                super
-              end
-            end
-          end.new(:channel_request, remote_id, "pty-req", false, *pty_data)
-        end
-      end
-    end
-  end
-end
 
 describe Kitchen::Transport::Ssh do
-
   let(:logged_output) { StringIO.new }
   let(:logger)        { Logger.new(logged_output) }
   let(:config)        { Hash.new }
   let(:state)         { Hash.new }
 
   let(:instance) do
-    stub(:name => "coolbeans", :logger => logger, :to_str => "instance")
+    stub(name: "coolbeans", logger: logger, to_str: "instance")
   end
 
   let(:transport) do
-    Kitchen::Transport::Ssh.new(config).finalize_config!(instance)
+    Net::SSH::Test::Extensions::IO.with_test_extension { Kitchen::Transport::Ssh.new(config).finalize_config!(instance) }
   end
 
   it "provisioner api_version is 1" do
@@ -138,7 +44,6 @@ describe Kitchen::Transport::Ssh do
   end
 
   describe "default_config" do
-
     it "sets :port to 22 by default" do
       transport[:port].must_equal 22
     end
@@ -198,7 +103,11 @@ describe Kitchen::Transport::Ssh do
     end
 
     it "sets :ssh_key to nil by default" do
-      transport[:ssh_key].must_equal nil
+      transport[:ssh_key].must_be_nil
+    end
+
+    it "sets :ssh_key_only to nil by default" do
+      transport[:ssh_key_only].must_be_nil
     end
 
     it "expands :ssh_path path if set" do
@@ -211,14 +120,53 @@ describe Kitchen::Transport::Ssh do
     it "sets :max_ssh_sessions to 9 by default" do
       transport[:max_ssh_sessions].must_equal 9
     end
+
+    it "sets :ssh_http_proxy to nil by default" do
+      transport[:ssh_http_proxy].must_be_nil
+    end
+
+    it "sets :ssh_http_proxy_port to nil by default" do
+      transport[:ssh_http_proxy_port].must_be_nil
+    end
+
+    it "sets :ssh_http_proxy_user to nil by default" do
+      transport[:ssh_http_proxy_user].must_be_nil
+    end
+
+    it "sets :ssh_http_proxy_password to nil by default" do
+      transport[:ssh_http_proxy_password].must_be_nil
+    end
+
+    it "sets :ssh_gateway to nil by default" do
+      transport[:ssh_gateway].must_be_nil
+    end
+
+    it "sets :ssh_gateway_username to nil by default" do
+      transport[:ssh_gateway_username].must_be_nil
+    end
+
+    it "sets :ssh_gateway_port to 22 by default" do
+      transport[:ssh_gateway_port].must_equal 22
+    end
   end
 
   describe "#connection" do
-
     let(:klass) { Kitchen::Transport::Ssh::Connection }
+    let(:options_http_proxy) { Hash.new }
+    let(:proxy_conn) do
+      state[:ssh_http_proxy]        = "ssh_http_proxy_from_state"
+      state[:ssh_http_proxy_port]   = "ssh_http_proxy_port_from_state"
+      options_http_proxy[:user]     = state[:ssh_http_proxy_user]
+      options_http_proxy[:password] = state[:ssh_http_proxy_password]
+      Net::SSH::Proxy::HTTP.new(state[:ssh_http_proxy], state[:ssh_http_proxy_port], options_http_proxy)
+    end
 
     # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
     def self.common_connection_specs
+      before do
+        Net::SSH::Proxy::HTTP.stubs(:new).returns(proxy_conn)
+      end
+
       it "returns a Kitchen::Transport::Ssh::Connection object" do
         transport.connection(state).must_be_kind_of klass
       end
@@ -239,9 +187,9 @@ describe Kitchen::Transport::Ssh do
         make_connection
       end
 
-      it "sets the :paranoid flag to false" do
+      it "sets the :verify_host_key flag to false" do
         klass.expects(:new).with do |hash|
-          hash[:paranoid] == false
+          hash[:verify_host_key] == false
         end
 
         make_connection
@@ -509,6 +457,16 @@ describe Kitchen::Transport::Ssh do
         make_connection
       end
 
+      it "sets :proxy to proxy if :ssh_http_proxy is set in state" do
+        config[:ssh_http_proxy] = true
+
+        klass.expects(:new).with do |hash|
+          hash[:proxy] == proxy_conn
+        end
+
+        make_connection
+      end
+
       it "sets :keys to an array if :ssh_key is set in config" do
         config[:kitchen_root] = "/r"
         config[:ssh_key] = "ssh_key_from_config"
@@ -589,6 +547,16 @@ describe Kitchen::Transport::Ssh do
         make_connection
       end
 
+      it "sets :auth_methods to only publickey if :ssh_key_only is set in config" do
+        config[:ssh_key_only] = true
+
+        klass.expects(:new).with do |hash|
+          hash[:auth_methods] == ["publickey"]
+        end
+
+        make_connection
+      end
+
       it "passes in :password if set in config" do
         config[:password] = "password_from_config"
 
@@ -642,14 +610,14 @@ describe Kitchen::Transport::Ssh do
         make_connection(state)
         make_connection(state)
 
-        logged_output.string.lines.count { |l|
+        logged_output.string.lines.count do |l|
           l =~ debug_line_with("[SSH] reusing existing connection ")
-        }.must_equal 1
+        end.must_equal 1
       end
 
       it "returns a new connection when called again if state differs" do
         first_connection  = make_connection(state)
-        second_connection = make_connection(state.merge(:port => 9000))
+        second_connection = make_connection(state.merge(port: 9000))
 
         first_connection.object_id.wont_equal second_connection.object_id
       end
@@ -658,22 +626,21 @@ describe Kitchen::Transport::Ssh do
         first_connection = make_connection(state)
         first_connection.expects(:close)
 
-        make_connection(state.merge(:port => 9000))
+        make_connection(state.merge(port: 9000))
       end
 
       it "logs a debug message a second connection is created" do
         make_connection(state)
-        make_connection(state.merge(:port => 9000))
+        make_connection(state.merge(port: 9000))
 
-        logged_output.string.lines.count { |l|
+        logged_output.string.lines.count do |l|
           l =~ debug_line_with("[SSH] shutting previous connection ")
-        }.must_equal 1
+        end.must_equal 1
       end
     end
     # rubocop:enable Metrics/MethodLength, Metrics/AbcSize
 
     describe "called without a block" do
-
       def make_connection(s = state)
         transport.connection(s)
       end
@@ -682,7 +649,6 @@ describe Kitchen::Transport::Ssh do
     end
 
     describe "called with a block" do
-
       def make_connection(s = state)
         transport.connection(s) do |conn|
           conn
@@ -694,12 +660,11 @@ describe Kitchen::Transport::Ssh do
   end
 
   def debug_line_with(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}}
+    /^D, .* : #{Regexp.escape(msg)}/
   end
 end
 
 describe Kitchen::Transport::Ssh::Connection do
-
   include Net::SSH::Test
   # sadly, Net:SSH::Test includes a #connection method so we'll alias this one
   # before redefining it
@@ -707,15 +672,15 @@ describe Kitchen::Transport::Ssh::Connection do
 
   let(:logged_output)   { StringIO.new }
   let(:logger)          { Logger.new(logged_output) }
-  let(:conn)            { net_ssh_connection }
+  let(:conn)            { Net::SSH::Test::Extensions::IO.with_test_extension { net_ssh_connection } }
 
   let(:options) do
     {
-      :logger => logger,
-      :username => "me",
-      :hostname => "foo",
-      :port => 22,
-      :max_ssh_sessions => 9
+      logger: logger,
+      username: "me",
+      hostname: "foo",
+      port: 22,
+      max_ssh_sessions: 9,
     }
   end
 
@@ -724,25 +689,18 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   before do
-    repatch_io
     logger.level = Logger::DEBUG
     Net::SSH.stubs(:start).returns(conn)
   end
 
-  after do
-    depatch_io
-  end
-
   describe "establishing a connection" do
-
     [
-      Errno::EACCES, Errno::EADDRINUSE, Errno::ECONNREFUSED, Errno::ETIMEDOUT,
-      Errno::ECONNRESET, Errno::ENETUNREACH, Errno::EHOSTUNREACH,
+      Errno::EACCES, Errno::EALREADY, Errno::EADDRINUSE, Errno::ECONNREFUSED, Errno::ETIMEDOUT,
+      Errno::ECONNRESET, Errno::ENETUNREACH, Errno::EHOSTUNREACH, Errno::EPIPE,
       Net::SSH::Disconnect, Net::SSH::AuthenticationFailed, Net::SSH::ConnectionTimeout,
       Timeout::Error
     ].each do |klass|
       describe "raising #{klass}" do
-
         before do
           Net::SSH.stubs(:start).raises(klass)
           options[:connection_retries] = 3
@@ -751,9 +709,9 @@ describe Kitchen::Transport::Ssh::Connection do
         end
 
         it "raises an SshFailed exception" do
-          e = proc {
+          e = proc do
             connection.execute("nope")
-          }.must_raise Kitchen::Transport::SshFailed
+          end.must_raise Kitchen::Transport::SshFailed
           e.message.must_match regexify("SSH session could not be established")
         end
 
@@ -764,9 +722,9 @@ describe Kitchen::Transport::Ssh::Connection do
             # the raise is not what is being tested here, rather its side-effect
           end
 
-          logged_output.string.lines.count { |l|
+          logged_output.string.lines.count do |l|
             l =~ debug_line("[SSH] opening connection to me@foo<{:port=>22}>")
-          }.must_equal 3
+          end.must_equal 3
         end
 
         it "sleeps for :connection_retry_sleep seconds between retries" do
@@ -787,10 +745,10 @@ describe Kitchen::Transport::Ssh::Connection do
             # the raise is not what is being tested here, rather its side-effect
           end
 
-          logged_output.string.lines.count { |l|
+          logged_output.string.lines.count do |l|
             l =~ info_line_with(
               "[SSH] connection failed, retrying in 7 seconds")
-          }.must_equal 2
+          end.must_equal 2
         end
 
         it "logs the last retry failures on warn" do
@@ -800,16 +758,15 @@ describe Kitchen::Transport::Ssh::Connection do
             # the raise is not what is being tested here, rather its side-effect
           end
 
-          logged_output.string.lines.count { |l|
+          logged_output.string.lines.count do |l|
             l =~ warn_line_with("[SSH] connection failed, terminating ")
-          }.must_equal 1
+          end.must_equal 1
         end
       end
     end
   end
 
   describe "#close" do
-
     before do
       story do |script|
         channel = script.opens_channel
@@ -848,9 +805,7 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   describe "#execute" do
-
     describe "for a successful command" do
-
       before do
         story do |script|
           channel = script.opens_channel
@@ -894,7 +849,6 @@ describe Kitchen::Transport::Ssh::Connection do
     end
 
     describe "for a failed command" do
-
       before do
         story do |script|
           channel = script.opens_channel
@@ -953,15 +907,15 @@ describe Kitchen::Transport::Ssh::Connection do
       end
 
       it "raises an SshFailed exception" do
-        err = proc {
-          connection.execute("doit")
-        }.must_raise Kitchen::Transport::SshFailed
+        err = proc do
+          assert_scripted { connection.execute("doit") }
+        end.must_raise Kitchen::Transport::SshFailed
         err.message.must_equal "SSH exited (42) for command: [doit]"
       end
 
       it "returns the exit code with an SshFailed exception" do
         begin
-          connection.execute("doit")
+          assert_scripted { connection.execute("doit") }
         rescue Kitchen::Transport::SshFailed => e
           e.exit_code.must_equal 42
         end
@@ -969,7 +923,6 @@ describe Kitchen::Transport::Ssh::Connection do
     end
 
     describe "for an interrupted command" do
-
       let(:conn) { mock("session") }
 
       before do
@@ -979,15 +932,14 @@ describe Kitchen::Transport::Ssh::Connection do
       it "raises SshFailed when an SSH exception is raised" do
         conn.stubs(:open_channel).raises(Net::SSH::Exception)
 
-        e = proc {
+        e = proc do
           connection.execute("nope")
-        }.must_raise Kitchen::Transport::SshFailed
+        end.must_raise Kitchen::Transport::SshFailed
         e.message.must_match regexify("SSH command failed")
       end
     end
 
     describe "for a nil command" do
-
       it "does not log on debug" do
         connection.execute(nil)
 
@@ -997,7 +949,6 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   describe "#login_command" do
-
     let(:login_command) { connection.login_command }
     let(:args)          { login_command.arguments.join(" ") }
 
@@ -1063,7 +1014,7 @@ describe Kitchen::Transport::Ssh::Connection do
     end
 
     it "sets SSH keys options if given" do
-      options[:keys] = %w[one two]
+      options[:keys] = %w{one two}
 
       args.must_match regexify(" -i one ")
       args.must_match regexify(" -i two ")
@@ -1081,9 +1032,7 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   describe "#upload" do
-
     describe "for a file" do
-
       let(:content) { "a" * 1234 }
 
       let(:src) do
@@ -1176,7 +1125,6 @@ describe Kitchen::Transport::Ssh::Connection do
     end
 
     describe "for a failed upload" do
-
       let(:conn) { mock("session") }
 
       before do
@@ -1186,23 +1134,94 @@ describe Kitchen::Transport::Ssh::Connection do
       it "raises SshFailed when an SSH exception is raised" do
         conn.stubs(:scp).raises(Net::SSH::Exception)
 
-        e = proc {
+        e = proc do
           connection.upload("nope", "fail")
-        }.must_raise Kitchen::Transport::SshFailed
+        end.must_raise Kitchen::Transport::SshFailed
         e.message.must_match regexify("SCP upload failed")
       end
     end
   end
 
-  describe "#wait_until_ready" do
+  describe "#download" do
+    let(:conn) { mock("session") }
+    let(:scp) { mock("scp") }
 
+    before do
+      Net::SSH.stubs(:start).returns(conn)
+      conn.stubs(:scp).returns(scp)
+      @local_parent = Dir.mktmpdir("dir")
+      @local = File.join(@local_parent, "local")
+    end
+
+    after do
+      FileUtils.remove_entry_secure(@local_parent)
+    end
+
+    describe "for a file" do
+      it "downloads a file from a remote over scp" do
+        FileUtils.expects(:mkdir_p).with(@local_parent)
+        scp.expects(:download!).with("/remote", @local)
+
+        connection.download("/remote", @local)
+      end
+    end
+
+    describe "for a list of files" do
+      it "downloads the files from a remote over scp" do
+        FileUtils.expects(:mkdir_p).with(@local_parent)
+        scp.expects(:download!).with("/remote-1", @local)
+        scp.expects(:download!).with("/remote-2", @local)
+
+        connection.download(["/remote-1", "/remote-2"], @local)
+      end
+    end
+
+    describe "for a directory" do
+      it "downloads the directory from a remote over scp" do
+        FileUtils.expects(:mkdir_p).with(@local_parent)
+        scp.expects(:download!).with("/remote-dir", @local).raises(Net::SCP::Error)
+        scp.expects(:download!).with("/remote-dir", @local, recursive: true)
+
+        connection.download("/remote-dir", @local)
+      end
+    end
+
+    describe "for a file that does not exist" do
+      it "logs a warning" do
+        FileUtils.expects(:mkdir_p).with(@local_parent)
+        scp.expects(:download!).with("/remote", @local).raises(Net::SCP::Error)
+        scp.expects(:download!).with("/remote", @local, recursive: true)
+          .raises(Net::SCP::Error)
+
+        connection.download("/remote", @local)
+
+        logged_output.string.lines.count do |l|
+          l =~ warn_line_with(
+            "SCP download failed for file or directory '/remote', perhaps it does not exist?"
+          )
+        end.must_equal 1
+      end
+    end
+
+    describe "for a failed download" do
+      it "raises SshFailed when an SSH exception is raised" do
+        conn.stubs(:scp).raises(Net::SSH::Exception)
+
+        e = proc do
+          connection.download("nope", "fail")
+        end.must_raise Kitchen::Transport::SshFailed
+        e.message.must_match regexify("SCP download failed")
+      end
+    end
+  end
+
+  describe "#wait_until_ready" do
     before do
       options[:max_wait_until_ready] = 300
       connection.stubs(:sleep)
     end
 
     describe "when failing to connect" do
-
       before do
         Net::SSH.stubs(:start).raises(Errno::ECONNREFUSED)
       end
@@ -1214,16 +1233,16 @@ describe Kitchen::Transport::Ssh::Connection do
           # the raise is not what is being tested here, rather its side-effect
         end
 
-        logged_output.string.lines.count { |l|
+        logged_output.string.lines.count do |l|
           l =~ info_line_with(
             "Waiting for SSH service on foo:22, retrying in 3 seconds")
-        }.must_equal((300 / 3) - 1)
-        logged_output.string.lines.count { |l|
+        end.must_equal((300 / 3) - 1)
+        logged_output.string.lines.count do |l|
           l =~ debug_line_with("[SSH] connection failed ")
-        }.must_equal((300 / 3) - 1)
-        logged_output.string.lines.count { |l|
+        end.must_equal((300 / 3) - 1)
+        logged_output.string.lines.count do |l|
           l =~ warn_line_with("[SSH] connection failed, terminating ")
-        }.must_equal 1
+        end.must_equal 1
       end
 
       it "sleeps for 3 seconds between retries" do
@@ -1239,7 +1258,6 @@ describe Kitchen::Transport::Ssh::Connection do
     end
 
     describe "when connection is successful" do
-
       before do
         story do |script|
           channel = script.opens_channel
@@ -1278,15 +1296,15 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   def debug_line(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}$}
+    /^D, .* : #{Regexp.escape(msg)}$/
   end
 
   def debug_line_with(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}}
+    /^D, .* : #{Regexp.escape(msg)}/
   end
 
   def info_line_with(msg)
-    %r{^I, .* : #{Regexp.escape(msg)}}
+    /^I, .* : #{Regexp.escape(msg)}/
   end
 
   def regexify(string)
@@ -1294,6 +1312,6 @@ describe Kitchen::Transport::Ssh::Connection do
   end
 
   def warn_line_with(msg)
-    %r{^W, .* : #{Regexp.escape(msg)}}
+    /^W, .* : #{Regexp.escape(msg)}/
   end
 end
