@@ -24,11 +24,8 @@ require "winrm-fs"
 require "winrm-elevated"
 
 module Kitchen
-
   module Transport
-
     class WinRMConnectionDummy < Kitchen::Transport::Winrm::Connection
-
       attr_reader :saved_command, :remote_path, :local_path
 
       def upload(locals, remote)
@@ -41,7 +38,6 @@ module Kitchen
 end
 
 describe Kitchen::Transport::Winrm do
-
   before do
     RbConfig::CONFIG.stubs(:[]).with("host_os").returns("blah")
   end
@@ -52,7 +48,7 @@ describe Kitchen::Transport::Winrm do
   let(:state)         { Hash.new }
 
   let(:instance) do
-    stub(:name => "coolbeans", :logger => logger, :to_str => "instance")
+    stub(name: "coolbeans", logger: logger, to_str: "instance")
   end
 
   let(:transport) do
@@ -72,6 +68,9 @@ describe Kitchen::Transport::Winrm do
   end
 
   describe "default_config" do
+    it "sets :scheme to http by default" do
+      transport[:scheme].must_equal "http"
+    end
 
     it "sets :port to 5985 by default" do
       transport[:port].must_equal 5985
@@ -82,12 +81,7 @@ describe Kitchen::Transport::Winrm do
     end
 
     it "sets :password to nil by default" do
-      transport[:password].must_equal nil
-    end
-
-    it "sets a default :endpoint_template value" do
-      transport[:endpoint_template].
-        must_equal "http://%{hostname}:%{port}/wsman"
+      transport[:password].must_be_nil
     end
 
     it "sets :rdp_port to 3389 by default" do
@@ -116,7 +110,6 @@ describe Kitchen::Transport::Winrm do
   end
 
   describe "#connection" do
-
     let(:klass) { Kitchen::Transport::Winrm::Connection }
 
     # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
@@ -124,6 +117,7 @@ describe Kitchen::Transport::Winrm do
       before do
         config[:hostname] = "here"
         config[:kitchen_root] = "/i/am/root"
+        config[:password] = "password"
       end
 
       it "returns a Kitchen::Transport::Winrm::Connection object" do
@@ -155,7 +149,7 @@ describe Kitchen::Transport::Winrm do
 
       it "sets the :winrm_transport to :negotiate" do
         klass.expects(:new).with do |hash|
-          hash[:winrm_transport] == :negotiate
+          hash[:transport] == :negotiate
         end
 
         make_connection
@@ -169,27 +163,37 @@ describe Kitchen::Transport::Winrm do
         make_connection
       end
 
+      it "sets :endpoint when hostname is an IPv6 address" do
+        config[:hostname] = "caec:cec6:c4ef:bb7b:1a78:d055:216d:3a78"
+
+        klass.expects(:new).with do |hash|
+          hash[:endpoint] == "http://[caec:cec6:c4ef:bb7b:1a78:d055:216d:3a78]:5985/wsman"
+        end
+
+        make_connection
+      end
+
       it "sets :endpoint from data in config" do
-        config[:hostname] = "host_from_config"
-        config[:port] = "port_from_config"
+        config[:hostname] = "host-from-config"
+        config[:port] = "42"
         config[:winrm_transport] = "ssl"
 
         klass.expects(:new).with do |hash|
-          hash[:endpoint] == "https://host_from_config:port_from_config/wsman"
+          hash[:endpoint] == "https://host-from-config:42/wsman"
         end
 
         make_connection
       end
 
       it "sets :endpoint from data in state over config data" do
-        state[:hostname] = "host_from_state"
-        config[:hostname] = "host_from_config"
-        state[:port] = "port_from_state"
-        config[:port] = "port_from_config"
+        state[:hostname] = "host-from-state"
+        config[:hostname] = "host-from-config"
+        state[:port] = "42"
+        config[:port] = "43"
         config[:winrm_transport] = "ssl"
 
         klass.expects(:new).with do |hash|
-          hash[:endpoint] == "https://host_from_state:port_from_state/wsman"
+          hash[:endpoint] == "https://host-from-state:42/wsman"
         end
 
         make_connection
@@ -220,7 +224,7 @@ describe Kitchen::Transport::Winrm do
         config[:password] = "pass_from_config"
 
         klass.expects(:new).with do |hash|
-          hash[:pass] == "pass_from_config"
+          hash[:password] == "pass_from_config"
         end
 
         make_connection
@@ -231,7 +235,7 @@ describe Kitchen::Transport::Winrm do
         config[:password] = "pass_from_config"
 
         klass.expects(:new).with do |hash|
-          hash[:pass] == "pass_from_state"
+          hash[:password] == "pass_from_state"
         end
 
         make_connection
@@ -325,7 +329,7 @@ describe Kitchen::Transport::Winrm do
         config[:winrm_transport] = "ssl"
 
         klass.expects(:new).with do |hash|
-          hash[:winrm_transport] == :ssl
+          hash[:transport] == :ssl
         end
 
         make_connection
@@ -390,9 +394,8 @@ describe Kitchen::Transport::Winrm do
         end
 
         it "sets :winrm_transport to negotiate" do
-
           klass.expects(:new).with do |hash|
-            hash[:winrm_transport] == :negotiate &&
+            hash[:transport] == :negotiate &&
               hash[:disable_sspi] == false &&
               hash[:basic_auth_only] == false
           end
@@ -412,14 +415,14 @@ describe Kitchen::Transport::Winrm do
         make_connection(state)
         make_connection(state)
 
-        logged_output.string.lines.count { |l|
+        logged_output.string.lines.count do |l|
           l =~ debug_line_with("[WinRM] reusing existing connection ")
-        }.must_equal 1
+        end.must_equal 1
       end
 
       it "returns a new connection when called again if state differs" do
         first_connection  = make_connection(state)
-        second_connection = make_connection(state.merge(:port => 9000))
+        second_connection = make_connection(state.merge(port: 9000))
 
         first_connection.object_id.wont_equal second_connection.object_id
       end
@@ -428,22 +431,21 @@ describe Kitchen::Transport::Winrm do
         first_connection = make_connection(state)
         first_connection.expects(:close)
 
-        make_connection(state.merge(:port => 9000))
+        make_connection(state.merge(port: 9000))
       end
 
       it "logs a debug message a second connection is created" do
         make_connection(state)
-        make_connection(state.merge(:port => 9000))
+        make_connection(state.merge(port: 9000))
 
-        logged_output.string.lines.count { |l|
+        logged_output.string.lines.count do |l|
           l =~ debug_line_with("[WinRM] shutting previous connection ")
-        }.must_equal 1
+        end.must_equal 1
       end
     end
     # rubocop:enable Metrics/MethodLength, Metrics/AbcSize
 
     describe "called without a block" do
-
       def make_connection(s = state)
         transport.connection(s)
       end
@@ -452,7 +454,6 @@ describe Kitchen::Transport::Winrm do
     end
 
     describe "called with a block" do
-
       def make_connection(s = state)
         transport.connection(s) do |conn|
           conn
@@ -527,8 +528,8 @@ describe Kitchen::Transport::Winrm do
       it "logs a message to fatal when libraries cannot be loaded" do
         transport = Kitchen::Transport::Winrm.new(config)
         transport.stubs(:require).with("winrm", anything)
-        transport.stubs(:require).with("winrm-fs").
-          raises(LoadError, "uh oh")
+        transport.stubs(:require).with("winrm-fs")
+          .raises(LoadError, "uh oh")
         begin
           transport.finalize_config!(instance)
         rescue # rubocop:disable Lint/HandleExceptions
@@ -542,12 +543,12 @@ describe Kitchen::Transport::Winrm do
       it "raises a UserError when libraries cannot be loaded" do
         transport = Kitchen::Transport::Winrm.new(config)
         transport.stubs(:require).with("winrm", anything)
-        transport.stubs(:require).with("winrm-fs").
-          raises(LoadError, "uh oh")
+        transport.stubs(:require).with("winrm-fs")
+          .raises(LoadError, "uh oh")
 
-        err = proc {
+        err = proc do
           transport.finalize_config!(instance)
-        }.must_raise Kitchen::UserError
+        end.must_raise Kitchen::UserError
         err.message.must_match(/^Could not load or activate winrm-fs\. /)
       end
     end
@@ -606,49 +607,53 @@ describe Kitchen::Transport::Winrm do
         transport.stubs(:require).with("winrm-fs", anything)
         transport.stubs(:require).raises(LoadError, "uh oh")
 
-        err = proc {
+        err = proc do
           transport.finalize_config!(instance)
-        }.must_raise Kitchen::UserError
+        end.must_raise Kitchen::UserError
         err.message.must_match(/^Could not load or activate winrm\. /)
       end
     end
   end
 
   def debug_line_with(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}}
+    /^D, .* : #{Regexp.escape(msg)}/
   end
 
   def fatal_line_with(msg)
-    %r{^F, .* : #{Regexp.escape(msg)}}
+    /^F, .* : #{Regexp.escape(msg)}/
   end
 end
 
 describe Kitchen::Transport::Winrm::Connection do
-
   let(:logged_output)   { StringIO.new }
   let(:logger)          { Logger.new(logged_output) }
 
   let(:options) do
-    { :logger => logger, :user => "me", :pass => "haha",
-      :endpoint => "http://foo:5985/wsman", :winrm_transport => :plaintext,
-      :kitchen_root => "/i/am/root", :instance_name => "coolbeans",
-      :rdp_port => "rdpyeah" }
+    { logger: logger, user: "me", password: "haha",
+      endpoint: "http://foo:5985/wsman", winrm_transport: :plaintext,
+      kitchen_root: "/i/am/root", instance_name: "coolbeans",
+      rdp_port: "rdpyeah" }
   end
 
   let(:info) do
-    copts = { :user => "me", :pass => "haha" }
-    "plaintext::http://foo:5985/wsman<#{copts}>"
+    copts = {
+      user: "me",
+      password: "haha",
+      endpoint: "http://foo:5985/wsman",
+      winrm_transport: :plaintext,
+    }
+    "<#{copts}>"
   end
 
   let(:winrm_session) do
     s = mock("winrm_session")
-    s.responds_like_instance_of(::WinRM::WinRMWebService)
+    s.responds_like_instance_of(::WinRM::Connection)
     s
   end
 
   let(:executor) do
     s = mock("command_executor")
-    s.responds_like_instance_of(WinRM::CommandExecutor)
+    s.responds_like_instance_of(WinRM::Shells::Powershell)
     s
   end
 
@@ -660,7 +665,7 @@ describe Kitchen::Transport::Winrm::Connection do
 
   let(:elevated_runner) do
     r = mock("elevated_runner")
-    r.responds_like_instance_of(WinRM::Elevated::Runner)
+    r.responds_like_instance_of(WinRM::Shells::Elevated)
     r
   end
 
@@ -669,27 +674,29 @@ describe Kitchen::Transport::Winrm::Connection do
   end
 
   before do
-    WinRM::WinRMWebService.stubs(:new).returns(winrm_session)
+    WinRM::Connection.stubs(:new).returns(winrm_session)
     winrm_session.stubs(:logger=)
     logger.level = Logger::DEBUG
   end
 
   describe "#close" do
-
     let(:response) do
       o = WinRM::Output.new
-      o[:exitcode] = 0
-      o[:data].concat([{ :stdout => "ok\r\n" }])
+      o.exitcode = 0
+      o << { stdout: "ok\r\n" }
       o
     end
 
     before do
-      winrm_session.stubs(:create_executor).returns(executor)
       transporter.stubs(:upload)
-      elevated_runner.stubs(:powershell_elevated).returns(response)
+      elevated_runner.stubs(:run).returns(response)
+      winrm_session.stubs(:shell).with(:powershell).returns(executor)
       executor.stubs(:close)
-      executor.stubs(:run_powershell_script).
-        with("doit").yields("ok\n", nil).returns(response)
+      elevated_runner.stubs(:close)
+      executor.stubs(:run)
+        .with("doit").yields("ok\n", nil).returns(response)
+      executor.stubs(:run)
+        .with("$env:temp").yields("ok\n", nil).returns(response)
     end
 
     it "only closes the shell once for multiple calls" do
@@ -711,9 +718,10 @@ describe Kitchen::Transport::Winrm::Connection do
 
     it "clears the elevated_runner executor" do
       options[:elevated] = true
-      options[:elevated_username] = options[:user]
-      options[:elevated_password] = options[:pass]
-      WinRM::Elevated::Runner.expects(:new).returns(elevated_runner).twice
+      elevated_runner.stubs(:username=)
+      elevated_runner.stubs(:password=)
+      elevated_runner.expects(:close).once
+      winrm_session.expects(:shell).with(:elevated).returns(elevated_runner).twice
 
       connection.execute("doit")
       connection.close
@@ -722,26 +730,22 @@ describe Kitchen::Transport::Winrm::Connection do
   end
 
   describe "#execute" do
-
     before do
-      winrm_session.stubs(:create_executor).returns(executor)
+      winrm_session.stubs(:shell).with(:powershell).returns(executor)
     end
 
     describe "for a successful command" do
-
       let(:response) do
         o = WinRM::Output.new
-        o[:exitcode] = 0
-        o[:data].concat([
-          { :stdout => "ok\r\n" },
-          { :stderr => "congrats\r\n" }
-        ])
+        o.exitcode = 0
+        o << { stdout: "ok\r\n" }
+        o << { stderr: "congrats\r\n" }
         o
       end
 
       before do
-        executor.expects(:run_powershell_script).
-          with("doit").yields("ok\n", nil).returns(response)
+        executor.expects(:run)
+          .with("doit").yields("ok\n", nil).returns(response)
       end
 
       it "logger displays command on debug" do
@@ -775,39 +779,40 @@ describe Kitchen::Transport::Winrm::Connection do
     describe "elevated command" do
       let(:response) do
         o = WinRM::Output.new
-        o[:exitcode] = 0
-        o[:data].concat([
-          { :stdout => "ok\r\n" },
-          { :stderr => "congrats\r\n" }
-        ])
+        o.exitcode = 0
+        o << { stdout: "ok\r\n" }
+        o << { stderr: "congrats\r\n" }
         o
       end
       let(:env_temp_response) do
         o = WinRM::Output.new
-        o[:exitcode] = 0
-        o[:data].concat([
-          { :stdout => "temp_dir" }
-        ])
+        o.exitcode = 0
+        o << { stdout: "temp_dir" }
         o
       end
+      let(:elevated_runner) do
+        r = mock("elevated_runner")
+        r.responds_like_instance_of(WinRM::Shells::Elevated)
+        r
+      end
 
       before do
         options[:elevated] = true
-        WinRM::Elevated::Runner.stubs(:new).with(executor).returns(elevated_runner)
+        winrm_session.stubs(:shell).with(:elevated).returns(elevated_runner)
       end
 
       describe "elevated user is not login user" do
         before do
           options[:elevated_username] = "username"
           options[:elevated_password] = "password"
-          executor.expects(:run_powershell_script).
-            with("$env:temp").returns(env_temp_response)
-          elevated_runner.expects(:powershell_elevated).
-            with(
-              "$env:temp='temp_dir';doit",
-              options[:elevated_username],
-              options[:elevated_password]
+          executor.expects(:run)
+            .with("$env:temp").returns(env_temp_response)
+          elevated_runner.expects(:run)
+            .with(
+              "$env:temp='temp_dir';doit"
             ).yields("ok\n", nil).returns(response)
+          elevated_runner.expects(:username=).with("username")
+          elevated_runner.expects(:password=).with("password")
         end
 
         it "logger captures stdout" do
@@ -817,16 +822,18 @@ describe Kitchen::Transport::Winrm::Connection do
         end
       end
 
-      describe "elevator user is login user" do
+      describe "elevated user is login user" do
         before do
           options[:elevated_username] = options[:user]
-          options[:elevated_password] = options[:pass]
-          elevated_runner.expects(:powershell_elevated).
-            with(
-              "doit",
-              options[:elevated_username],
-              options[:elevated_password]
+          options[:elevated_password] = options[:password]
+          executor.expects(:run)
+            .with("$env:temp").returns(env_temp_response)
+          elevated_runner.expects(:run)
+            .with(
+              "$env:temp='temp_dir';doit"
             ).yields("ok\n", nil).returns(response)
+          elevated_runner.expects(:username=).with(options[:user])
+          elevated_runner.expects(:password=).with(options[:password])
         end
 
         it "logger captures stdout" do
@@ -837,70 +844,35 @@ describe Kitchen::Transport::Winrm::Connection do
       end
     end
 
-    describe "long command" do
-      let(:command) { %{Write-Host "#{"a" * 4000}"} }
-
-      let(:connection) do
-        Kitchen::Transport::WinRMConnectionDummy.new(options)
-      end
-
-      let(:response) do
-        o = WinRM::Output.new
-        o[:exitcode] = 0
-        o[:data].concat([
-          { :stdout => "ok\r\n" },
-          { :stderr => "congrats\r\n" }
-        ])
-        o
-      end
-
-      before do
-        executor.expects(:run_powershell_script).with(
-          %{powershell -ExecutionPolicy Bypass -File "$env:TEMP/coolbeans-long_script.ps1"}
-        ).yields("ok\n", nil).returns(response)
-      end
-
-      it "uploads the long command" do
-        with_fake_fs do
-          connection.execute(command)
-
-          connection.saved_command.must_equal command
-        end
-      end
-    end
-
     describe "for a failed command" do
-
       let(:response) do
         o = WinRM::Output.new
-        o[:exitcode] = 1
-        o[:data].concat([
-          { :stderr => "#< CLIXML\r\n" },
-          { :stderr => "<Objs Version=\"1.1.0.1\" xmlns=\"http://schemas." },
-          { :stderr => "microsoft.com/powershell/2004/04\"><S S=\"Error\">" },
-          { :stderr => "doit : The term 'doit' is not recognized as the " },
-          { :stderr => "name of a cmdlet, function, _x000D__x000A_</S>" },
-          { :stderr => "<S S=\"Error\">script file, or operable program. " },
-          { :stderr => "Check the spelling of" },
-          { :stderr => "the name, or if a path _x000D__x000A_</S><S S=\"E" },
-          { :stderr => "rror\">was included, verify that the path is corr" },
-          { :stderr => "ect and try again._x000D__x000A_</S><S S=\"Error" },
-          { :stderr => "\">At line:1 char:1_x000D__x000A_</S><S S=\"Error" },
-          { :stderr => "\">+ doit_x000D__x000A_</S><S S=\"Error\">+ ~~~~_" },
-          { :stderr => "x000D__x000A_</S><S S=\"Error\">    + CategoryInf" },
-          { :stderr => "o          : ObjectNotFound: (doit:String) [], Co" },
-          { :stderr => "mmandNotFoun _x000D__x000A_</S><S S=\"Error\">   " },
-          { :stderr => "dException_x000D__x000A_</S><S S=\"Error\">    + " },
-          { :stderr => "FullyQualifiedErrorId : CommandNotFoundException_" },
-          { :stderr => "x000D__x000A_</S><S S=\"Error\"> _x000D__x000A_</" },
-          { :stderr => "S></Objs>" }
-        ])
+        o.exitcode = 1
+        o << { stderr: "#< CLIXML\r\n" }
+        o << { stderr: '<Objs Version="1.1.0.1" xmlns="http://schemas.' }
+        o << { stderr: 'microsoft.com/powershell/2004/04"><S S="Error">' }
+        o << { stderr: "doit : The term 'doit' is not recognized as the " }
+        o << { stderr: "name of a cmdlet, function, _x000D__x000A_</S>" }
+        o << { stderr: '<S S="Error">script file, or operable program. ' }
+        o << { stderr: "Check the spelling of" }
+        o << { stderr: 'the name, or if a path _x000D__x000A_</S><S S="E' }
+        o << { stderr: 'rror">was included, verify that the path is corr' }
+        o << { stderr: 'ect and try again._x000D__x000A_</S><S S="Error' }
+        o << { stderr: '">At line:1 char:1_x000D__x000A_</S><S S="Error' }
+        o << { stderr: '">+ doit_x000D__x000A_</S><S S="Error">+ ~~~~_' }
+        o << { stderr: 'x000D__x000A_</S><S S="Error">    + CategoryInf' }
+        o << { stderr: "o          : ObjectNotFound: (doit:String) [], Co" }
+        o << { stderr: 'mmandNotFoun _x000D__x000A_</S><S S="Error">   ' }
+        o << { stderr: 'dException_x000D__x000A_</S><S S="Error">    + ' }
+        o << { stderr: "FullyQualifiedErrorId : CommandNotFoundException_" }
+        o << { stderr: 'x000D__x000A_</S><S S="Error"> _x000D__x000A_</' }
+        o << { stderr: "S></Objs>" }
         o
       end
 
       before do
-        executor.expects(:run_powershell_script).
-          with("doit").yields("nope\n", nil).returns(response)
+        executor.expects(:run)
+          .with("doit").yields("nope\n", nil).returns(response)
       end
 
       # rubocop:disable Metrics/MethodLength
@@ -954,13 +926,12 @@ MSG
       # rubocop:enable Metrics/MethodLength
 
       describe "when a non-zero exit code is returned" do
-
         common_failed_command_specs
 
         it "raises a WinrmFailed exception" do
-          err = proc {
+          err = proc do
             connection.execute("doit")
-          }.must_raise Kitchen::Transport::WinrmFailed
+          end.must_raise Kitchen::Transport::WinrmFailed
           err.message.must_equal "WinRM exited (1) for command: [doit]"
         end
 
@@ -975,7 +946,6 @@ MSG
     end
 
     describe "for a nil command" do
-
       it "does not log on debug" do
         executor.expects(:open).never
         connection.execute(nil)
@@ -991,18 +961,17 @@ MSG
       HTTPClient::KeepAliveDisconnected, HTTPClient::ConnectTimeoutError
     ].each do |klass|
       describe "raising #{klass}" do
-
         before do
           k = if klass == ::WinRM::WinRMHTTPTransportError
             # this exception takes 2 args in its constructor, which is not stock
-            klass.new("dang", 200)
-          else
-            klass
-          end
+                klass.new("dang", 200)
+              else
+                klass
+              end
 
           options[:connection_retries] = 3
           options[:connection_retry_sleep] = 7
-          winrm_session.stubs(:create_executor).raises(k)
+          winrm_session.stubs(:shell).with(:powershell).raises(k)
         end
 
         it "reraises the #{klass} exception" do
@@ -1013,7 +982,6 @@ MSG
   end
 
   describe "#login_command" do
-
     let(:login_command) { connection.login_command }
     let(:args)          { login_command.arguments.join(" ") }
     let(:exec_args)     { login_command.exec_args }
@@ -1023,7 +991,6 @@ MSG
     end
 
     describe "for Mac-based workstations" do
-
       before do
         RbConfig::CONFIG.stubs(:[]).with("host_os").returns("darwin14")
       end
@@ -1081,7 +1048,6 @@ MSG
     end
 
     describe "for Windows-based workstations" do
-
       before do
         RbConfig::CONFIG.stubs(:[]).with("host_os").returns("mingw32")
       end
@@ -1137,7 +1103,6 @@ MSG
     end
 
     describe "for Linux-based workstations" do
-
       before do
         RbConfig::CONFIG.stubs(:[]).with("host_os").returns("linux-gnu")
       end
@@ -1160,14 +1125,13 @@ MSG
       end
 
       it "won't set the pass if not given" do
-        options.delete(:pass)
+        options.delete(:password)
 
         args.wont_match regexify(" -p haha ")
       end
     end
 
     describe "for unknown workstation platforms" do
-
       before do
         RbConfig::CONFIG.stubs(:[]).with("host_os").returns("cray")
       end
@@ -1181,12 +1145,11 @@ MSG
   end
 
   describe "#upload" do
-
     before do
-      winrm_session.stubs(:create_executor).returns(executor)
+      winrm_session.stubs(:shell).with(:powershell).returns(executor)
 
-      WinRM::FS::Core::FileTransporter.stubs(:new).
-        with(executor).returns(transporter)
+      WinRM::FS::Core::FileTransporter.stubs(:new)
+        .with(executor).returns(transporter)
       transporter.stubs(:upload)
     end
 
@@ -1194,8 +1157,8 @@ MSG
       it "builds a Winrm::FileTransporter" do
         WinRM::FS::Core::FileTransporter.unstub(:new)
 
-        WinRM::FS::Core::FileTransporter.expects(:new).
-          with(executor).returns(transporter)
+        WinRM::FS::Core::FileTransporter.expects(:new)
+          .with(executor).returns(transporter)
 
         upload
       end
@@ -1203,8 +1166,8 @@ MSG
       it "reuses the Winrm::FileTransporter" do
         WinRM::FS::Core::FileTransporter.unstub(:new)
 
-        WinRM::FS::Core::FileTransporter.expects(:new).
-          with(executor).returns(transporter).once
+        WinRM::FS::Core::FileTransporter.expects(:new)
+          .with(executor).returns(transporter).once
 
         upload
         upload
@@ -1213,18 +1176,16 @@ MSG
     end
 
     describe "for a file" do
-
       def upload # execute every time, not lazily once
-        connection.upload("/tmp/file.txt", "C:\\dest")
+        connection.upload("/tmp/file.txt", 'C:\\dest')
       end
 
       common_specs_for_upload
     end
 
     describe "for a collection of files" do
-
       def upload # execute every time, not lazily once
-        connection.upload(%W[/tmp/file1.txt /tmp/file2.txt], "C:\\dest")
+        connection.upload(%w{/tmp/file1.txt /tmp/file2.txt}, 'C:\\dest')
       end
 
       common_specs_for_upload
@@ -1232,24 +1193,22 @@ MSG
   end
 
   describe "#wait_until_ready" do
-
     before do
-      winrm_session.stubs(:create_executor).returns(executor)
+      winrm_session.stubs(:shell).with(:powershell).returns(executor)
       options[:max_wait_until_ready] = 300
     end
 
     describe "when connection is successful" do
-
       let(:response) do
         o = WinRM::Output.new
-        o[:exitcode] = 0
-        o[:data].concat([{ :stdout => "[WinRM] Established\r\n" }])
+        o.exitcode = 0
+        o << { stdout: "[WinRM] Established\r\n" }
         o
       end
 
       before do
-        executor.expects(:run_powershell_script).
-          with("Write-Host '[WinRM] Established\n'").returns(response)
+        executor.expects(:run)
+          .with("Write-Host '[WinRM] Established\n'").returns(response)
       end
 
       it "executes an empty command string to ensure working" do
@@ -1258,23 +1217,22 @@ MSG
     end
 
     describe "when connection suceeds but command fails, sad panda" do
-
       let(:response) do
         o = WinRM::Output.new
-        o[:exitcode] = 42
-        o[:data].concat([{ :stderr => "Ah crap.\r\n" }])
+        o.exitcode = 42
+        o << { stderr: "Ah crap.\r\n" }
         o
       end
 
       before do
-        executor.expects(:run_powershell_script).
-          with("Write-Host '[WinRM] Established\n'").returns(response)
+        executor.expects(:run)
+          .with("Write-Host '[WinRM] Established\n'").returns(response)
       end
 
       it "executes an empty command string to ensure working" do
-        err = proc {
+        err = proc do
           connection.wait_until_ready
-        }.must_raise Kitchen::Transport::WinrmFailed
+        end.must_raise Kitchen::Transport::WinrmFailed
         err.message.must_equal "WinRM exited (42) for command: " \
           "[Write-Host '[WinRM] Established\n']"
       end
@@ -1292,24 +1250,24 @@ MSG
   end
 
   def debug_output(output)
-    regexp = %r{^D, .* DEBUG -- : }
-    output.lines.grep(%r{^D, .* DEBUG -- : }).map { |l| l.sub(regexp, "") }.join
+    regexp = /^D, .* DEBUG -- : /
+    output.lines.grep(/^D, .* DEBUG -- : /).map { |l| l.sub(regexp, "") }.join
   end
 
   def debug_line(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}$}
+    /^D, .* : #{Regexp.escape(msg)}$/
   end
 
   def debug_line_with(msg)
-    %r{^D, .* : #{Regexp.escape(msg)}}
+    /^D, .* : #{Regexp.escape(msg)}/
   end
 
   def info_line(msg)
-    %r{^I, .* : #{Regexp.escape(msg)}$}
+    /^I, .* : #{Regexp.escape(msg)}$/
   end
 
   def info_line_with(msg)
-    %r{^I, .* : #{Regexp.escape(msg)}}
+    /^I, .* : #{Regexp.escape(msg)}/
   end
 
   def regexify(string)
@@ -1317,10 +1275,10 @@ MSG
   end
 
   def warn_line(msg)
-    %r{^W, .* : #{Regexp.escape(msg)}$}
+    /^W, .* : #{Regexp.escape(msg)}$/
   end
 
   def warn_line_with(msg)
-    %r{^W, .* : #{Regexp.escape(msg)}}
+    /^W, .* : #{Regexp.escape(msg)}/
   end
 end
